# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/analysis/summarization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/speechsense/v1/analysis/summarization.proto\x12$yandex.cloud.speechsense.v1.analysis\"a\n\rSummarization\x12P\n\nstatements\x18\x01 \x03(\x0b\x32<.yandex.cloud.speechsense.v1.analysis.SummarizationStatement\"s\n\x16SummarizationStatement\x12G\n\x05\x66ield\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.speechsense.v1.analysis.SummarizationField\x12\x10\n\x08response\x18\x02 \x03(\t\"z\n\x12SummarizationField\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12J\n\x04type\x18\x02 \x01(\x0e\x32<.yandex.cloud.speechsense.v1.analysis.SummarizationFieldType*\\\n\x16SummarizationFieldType\x12(\n$SUMMARIZATION_FIELD_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04TEXT\x10\x01\x12\x0e\n\nTEXT_ARRAY\x10\x02\x42\x94\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x12SummarizationProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.summarization_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\022SummarizationProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_SUMMARIZATIONFIELDTYPE']._serialized_start=438
  _globals['_SUMMARIZATIONFIELDTYPE']._serialized_end=530
  _globals['_SUMMARIZATION']._serialized_start=98
  _globals['_SUMMARIZATION']._serialized_end=195
  _globals['_SUMMARIZATIONSTATEMENT']._serialized_start=197
  _globals['_SUMMARIZATIONSTATEMENT']._serialized_end=312
  _globals['_SUMMARIZATIONFIELD']._serialized_start=314
  _globals['_SUMMARIZATIONFIELD']._serialized_end=436
# @@protoc_insertion_point(module_scope)
