# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/eventrouter/v1/bus.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/serverless/eventrouter/v1/bus.proto\x12&yandex.cloud.serverless.eventrouter.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xac\x03\n\x03\x42us\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12G\n\x06labels\x18\x07 \x03(\x0b\x32\x37.yandex.cloud.serverless.eventrouter.v1.Bus.LabelsEntry\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x12\x42\n\x06status\x18\t \x01(\x0e\x32\x32.yandex.cloud.serverless.eventrouter.v1.Bus.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42\x8a\x01\n*yandex.cloud.api.serverless.eventrouter.v1B\x04PERBZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.eventrouter.v1.bus_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.serverless.eventrouter.v1B\004PERBZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/eventrouter/v1;eventrouter'
  _BUS_LABELSENTRY._options = None
  _BUS_LABELSENTRY._serialized_options = b'8\001'
  _globals['_BUS']._serialized_start=126
  _globals['_BUS']._serialized_end=554
  _globals['_BUS_LABELSENTRY']._serialized_start=435
  _globals['_BUS_LABELSENTRY']._serialized_end=480
  _globals['_BUS_STATUS']._serialized_start=482
  _globals['_BUS_STATUS']._serialized_end=554
# @@protoc_insertion_point(module_scope)
