"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HostType(google.protobuf.message.Message):
    """Represents host resources.
    Note: Platform can use hosts with different number of memory and cores.
    TODO: Do we need sockets here?
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    DISKS_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique type identifier."""
    cores: builtins.int
    """Total number of cores available for instances."""
    memory: builtins.int
    """Ammount of memory available for instances."""
    disks: builtins.int
    """Number of local disks available for instances"""
    disk_size: builtins.int
    """Size of each local disk"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cores: builtins.int = ...,
        memory: builtins.int = ...,
        disks: builtins.int = ...,
        disk_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cores", b"cores", "disk_size", b"disk_size", "disks", b"disks", "id", b"id", "memory", b"memory"]) -> None: ...

global___HostType = HostType
