# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/agent/log_settings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/loadtesting/api/v1/agent/log_settings.proto\x12%yandex.cloud.loadtesting.api.v1.agent\x1a\x1dyandex/cloud/validation.proto\"3\n\x0bLogSettings\x12$\n\x12\x63loud_log_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50B|\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.agent.log_settings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agent'
  _LOGSETTINGS.fields_by_name['cloud_log_group_id']._options = None
  _LOGSETTINGS.fields_by_name['cloud_log_group_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LOGSETTINGS']._serialized_start=130
  _globals['_LOGSETTINGS']._serialized_end=181
# @@protoc_insertion_point(module_scope)
