# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/mdb/kafka/v1/connector.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xa5\x03\n\rConnectorSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ttasks_max\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\nproperties\x18\x03 \x03(\x0b\x32\x38.yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry\x12\x61\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x39.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpecH\x00\x12X\n\x18\x63onnector_config_s3_sink\x18\x0b \x01(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.ConnectorConfigS3SinkSpecH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10\x63onnector_configJ\x04\x08\x04\x10\n\"\xa9\x03\n\x13UpdateConnectorSpec\x12.\n\ttasks_max\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12R\n\nproperties\x18\x02 \x03(\x0b\x32>.yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry\x12\x61\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x39.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpecH\x00\x12^\n\x18\x63onnector_config_s3_sink\x18\x0b \x01(\x0b\x32:.yandex.cloud.mdb.kafka.v1.UpdateConnectorConfigS3SinkSpecH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10\x63onnector_configJ\x04\x08\x03\x10\n\"\xfd\x01\n\x1e\x43onnectorConfigMirrorMakerSpec\x12H\n\x0esource_cluster\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec\x12H\n\x0etarget_cluster\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec\x12\x0e\n\x06topics\x18\x03 \x01(\t\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xd6\x01\n\x15\x43lusterConnectionSpec\x12\r\n\x05\x61lias\x18\x01 \x01(\t\x12\x42\n\x0cthis_cluster\x18\x02 \x01(\x0b\x32*.yandex.cloud.mdb.kafka.v1.ThisClusterSpecH\x00\x12T\n\x10\x65xternal_cluster\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpecH\x00\x42\x14\n\x12\x63luster_connection\"\x11\n\x0fThisClusterSpec\"\xc0\x01\n\x1d\x45xternalClusterConnectionSpec\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\x15\n\rsasl_username\x18\x02 \x01(\t\x12\x15\n\rsasl_password\x18\x03 \x01(\t\x12\x16\n\x0esasl_mechanism\x18\x04 \x01(\t\x12\x19\n\x11security_protocol\x18\x05 \x01(\t\x12#\n\x1bssl_truststore_certificates\x18\x06 \x01(\t\"\xc5\x01\n\x19\x43onnectorConfigS3SinkSpec\x12\x0e\n\x06topics\x18\x01 \x01(\t\x12\x1d\n\x15\x66ile_compression_type\x18\x02 \x01(\t\x12\x35\n\x10\x66ile_max_records\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rs3_connection\x18\x04 \x01(\x0b\x32+.yandex.cloud.mdb.kafka.v1.S3ConnectionSpec\"\xac\x01\n\x1fUpdateConnectorConfigS3SinkSpec\x12\x0e\n\x06topics\x18\x01 \x01(\t\x12\x35\n\x10\x66ile_max_records\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rs3_connection\x18\x03 \x01(\x0b\x32+.yandex.cloud.mdb.kafka.v1.S3ConnectionSpec\"{\n\x10S3ConnectionSpec\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12G\n\x0b\x65xternal_s3\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ExternalS3StorageSpecH\x00\x42\t\n\x07storage\"k\n\x15\x45xternalS3StorageSpec\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x19\n\x11secret_access_key\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\"\x98\x05\n\tConnector\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ttasks_max\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12H\n\nproperties\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry\x12;\n\x06health\x18\x04 \x01(\x0e\x32+.yandex.cloud.mdb.kafka.v1.Connector.Health\x12;\n\x06status\x18\x05 \x01(\x0e\x32+.yandex.cloud.mdb.kafka.v1.Connector.Status\x12\x12\n\ncluster_id\x18\x06 \x01(\t\x12]\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x35.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerH\x00\x12T\n\x18\x63onnector_config_s3_sink\x18\x0b \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ConnectorConfigS3SinkH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"@\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\n\n\x06PAUSED\x10\x03\x42\x12\n\x10\x63onnector_configJ\x04\x08\x07\x10\n\"\xf1\x01\n\x1a\x43onnectorConfigMirrorMaker\x12\x44\n\x0esource_cluster\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ClusterConnection\x12\x44\n\x0etarget_cluster\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ClusterConnection\x12\x0e\n\x06topics\x18\x03 \x01(\t\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xca\x01\n\x11\x43lusterConnection\x12\r\n\x05\x61lias\x18\x01 \x01(\t\x12>\n\x0cthis_cluster\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.kafka.v1.ThisClusterH\x00\x12P\n\x10\x65xternal_cluster\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionH\x00\x42\x14\n\x12\x63luster_connection\"\r\n\x0bThisCluster\"\x86\x01\n\x19\x45xternalClusterConnection\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\x15\n\rsasl_username\x18\x02 \x01(\t\x12\x16\n\x0esasl_mechanism\x18\x04 \x01(\t\x12\x19\n\x11security_protocol\x18\x05 \x01(\tJ\x04\x08\x03\x10\x04\"\xbd\x01\n\x15\x43onnectorConfigS3Sink\x12\x0e\n\x06topics\x18\x01 \x01(\t\x12\x1d\n\x15\x66ile_compression_type\x18\x02 \x01(\t\x12\x35\n\x10\x66ile_max_records\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\rs3_connection\x18\x04 \x01(\x0b\x32\'.yandex.cloud.mdb.kafka.v1.S3Connection\"s\n\x0cS3Connection\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x43\n\x0b\x65xternal_s3\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ExternalS3StorageH\x00\x42\t\n\x07storage\"L\n\x11\x45xternalS3Storage\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\tBd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _CONNECTORSPEC_PROPERTIESENTRY._options = None
  _CONNECTORSPEC_PROPERTIESENTRY._serialized_options = b'8\001'
  _UPDATECONNECTORSPEC_PROPERTIESENTRY._options = None
  _UPDATECONNECTORSPEC_PROPERTIESENTRY._serialized_options = b'8\001'
  _CONNECTOR_PROPERTIESENTRY._options = None
  _CONNECTOR_PROPERTIESENTRY._serialized_options = b'8\001'
  _globals['_CONNECTORSPEC']._serialized_start=105
  _globals['_CONNECTORSPEC']._serialized_end=526
  _globals['_CONNECTORSPEC_PROPERTIESENTRY']._serialized_start=451
  _globals['_CONNECTORSPEC_PROPERTIESENTRY']._serialized_end=500
  _globals['_UPDATECONNECTORSPEC']._serialized_start=529
  _globals['_UPDATECONNECTORSPEC']._serialized_end=954
  _globals['_UPDATECONNECTORSPEC_PROPERTIESENTRY']._serialized_start=451
  _globals['_UPDATECONNECTORSPEC_PROPERTIESENTRY']._serialized_end=500
  _globals['_CONNECTORCONFIGMIRRORMAKERSPEC']._serialized_start=957
  _globals['_CONNECTORCONFIGMIRRORMAKERSPEC']._serialized_end=1210
  _globals['_CLUSTERCONNECTIONSPEC']._serialized_start=1213
  _globals['_CLUSTERCONNECTIONSPEC']._serialized_end=1427
  _globals['_THISCLUSTERSPEC']._serialized_start=1429
  _globals['_THISCLUSTERSPEC']._serialized_end=1446
  _globals['_EXTERNALCLUSTERCONNECTIONSPEC']._serialized_start=1449
  _globals['_EXTERNALCLUSTERCONNECTIONSPEC']._serialized_end=1641
  _globals['_CONNECTORCONFIGS3SINKSPEC']._serialized_start=1644
  _globals['_CONNECTORCONFIGS3SINKSPEC']._serialized_end=1841
  _globals['_UPDATECONNECTORCONFIGS3SINKSPEC']._serialized_start=1844
  _globals['_UPDATECONNECTORCONFIGS3SINKSPEC']._serialized_end=2016
  _globals['_S3CONNECTIONSPEC']._serialized_start=2018
  _globals['_S3CONNECTIONSPEC']._serialized_end=2141
  _globals['_EXTERNALS3STORAGESPEC']._serialized_start=2143
  _globals['_EXTERNALS3STORAGESPEC']._serialized_end=2250
  _globals['_CONNECTOR']._serialized_start=2253
  _globals['_CONNECTOR']._serialized_end=2917
  _globals['_CONNECTOR_PROPERTIESENTRY']._serialized_start=451
  _globals['_CONNECTOR_PROPERTIESENTRY']._serialized_end=500
  _globals['_CONNECTOR_HEALTH']._serialized_start=2776
  _globals['_CONNECTOR_HEALTH']._serialized_end=2825
  _globals['_CONNECTOR_STATUS']._serialized_start=2827
  _globals['_CONNECTOR_STATUS']._serialized_end=2891
  _globals['_CONNECTORCONFIGMIRRORMAKER']._serialized_start=2920
  _globals['_CONNECTORCONFIGMIRRORMAKER']._serialized_end=3161
  _globals['_CLUSTERCONNECTION']._serialized_start=3164
  _globals['_CLUSTERCONNECTION']._serialized_end=3366
  _globals['_THISCLUSTER']._serialized_start=3368
  _globals['_THISCLUSTER']._serialized_end=3381
  _globals['_EXTERNALCLUSTERCONNECTION']._serialized_start=3384
  _globals['_EXTERNALCLUSTERCONNECTION']._serialized_end=3518
  _globals['_CONNECTORCONFIGS3SINK']._serialized_start=3521
  _globals['_CONNECTORCONFIGS3SINK']._serialized_end=3710
  _globals['_S3CONNECTION']._serialized_start=3712
  _globals['_S3CONNECTION']._serialized_end=3827
  _globals['_EXTERNALS3STORAGE']._serialized_start=3829
  _globals['_EXTERNALS3STORAGE']._serialized_end=3905
# @@protoc_insertion_point(module_scope)
