# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/report/status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/loadtesting/api/v1/report/status.proto\x12&yandex.cloud.loadtesting.api.v1.report*L\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0e\n\nCOLLECTING\x10\x01\x12\x0f\n\x0b\x43\x41LCULATING\x10\x02\x12\t\n\x05READY\x10\x03\x42\x7f\n*yandex.cloud.api.loadtesting.api.v1.reportZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report;reportb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.report.status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.loadtesting.api.v1.reportZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report;report'
  _globals['_STATUS']._serialized_start=95
  _globals['_STATUS']._serialized_end=171
# @@protoc_insertion_point(module_scope)
