"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DescriptiveStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    MEAN_FIELD_NUMBER: builtins.int
    STD_FIELD_NUMBER: builtins.int
    QUANTILES_FIELD_NUMBER: builtins.int
    min: builtins.float
    """Minimum observed value"""
    max: builtins.float
    """Maximum observed value"""
    mean: builtins.float
    """Estimated mean of distribution"""
    std: builtins.float
    """Estimated standard deviation of distribution"""
    @property
    def quantiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Quantile]:
        """List of evaluated quantiles"""

    def __init__(
        self,
        *,
        min: builtins.float = ...,
        max: builtins.float = ...,
        mean: builtins.float = ...,
        std: builtins.float = ...,
        quantiles: collections.abc.Iterable[global___Quantile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max", b"max", "mean", b"mean", "min", b"min", "quantiles", b"quantiles", "std", b"std"]) -> None: ...

global___DescriptiveStatistics = DescriptiveStatistics

@typing.final
class Quantile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEVEL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    level: builtins.float
    """Quantile level in range (0, 1)"""
    value: builtins.float
    """Quantile value"""
    def __init__(
        self,
        *,
        level: builtins.float = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["level", b"level", "value", b"value"]) -> None: ...

global___Quantile = Quantile

@typing.final
class AudioSegmentBoundaries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_MS_FIELD_NUMBER: builtins.int
    END_TIME_MS_FIELD_NUMBER: builtins.int
    DURATION_SECONDS_FIELD_NUMBER: builtins.int
    start_time_ms: builtins.int
    """Audio segment start time"""
    end_time_ms: builtins.int
    """Audio segment end time"""
    duration_seconds: builtins.int
    """Duration in seconds"""
    def __init__(
        self,
        *,
        start_time_ms: builtins.int = ...,
        end_time_ms: builtins.int = ...,
        duration_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["duration_seconds", b"duration_seconds", "end_time_ms", b"end_time_ms", "start_time_ms", b"start_time_ms"]) -> None: ...

global___AudioSegmentBoundaries = AudioSegmentBoundaries
