"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BillingAccount(google.protobuf.message.Message):
    """A BillingAccount resource. For more information, see [BillingAccount](/docs/billing/concepts/billing-account)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    CURRENCY_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    BALANCE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the billing account."""
    name: builtins.str
    """Name of the billing account."""
    country_code: builtins.str
    """ISO 3166-1 alpha-2 country code of the billing account."""
    currency: builtins.str
    """Currency of the billing account.
    Can be one of the following:
    * `RUB`
    * `USD`
    * `KZT`
    """
    active: builtins.bool
    """Represents whether corresponding billable objects can be used or not."""
    balance: builtins.str
    """Current balance of the billing account."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        country_code: builtins.str = ...,
        currency: builtins.str = ...,
        active: builtins.bool = ...,
        balance: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["active", b"active", "balance", b"balance", "country_code", b"country_code", "created_at", b"created_at", "currency", b"currency", "id", b"id", "name", b"name"]) -> None: ...

global___BillingAccount = BillingAccount
