# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/lockbox/v1/secret_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.lockbox.v1 import secret_pb2 as yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/lockbox/v1/secret_service.proto\x12\x17yandex.cloud.lockbox.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a$yandex/cloud/lockbox/v1/secret.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\x98\x01\n\x12PayloadEntryChange\x12\x31\n\x03key\x18\x01 \x01(\tB$\xe8\xc7\x31\x01\xf2\xc7\x31\x13[-_./\\\\@0-9a-zA-Z]+\x8a\xc8\x31\x05<=256\x12!\n\ntext_value\x18\x02 \x01(\tB\x0b\x8a\xc8\x31\x07<=65536H\x00\x12#\n\x0c\x62inary_value\x18\x03 \x01(\x0c\x42\x0b\x8a\xc8\x31\x07<=65536H\x00\x42\x07\n\x05value\"3\n\x10GetSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"s\n\x12ListSecretsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"`\n\x13ListSecretsResponse\x12\x30\n\x07secrets\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.lockbox.v1.Secret\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdc\x04\n\x13\x43reateSecretRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x85\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x38.yandex.cloud.lockbox.v1.CreateSecretRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x1c\n\nkms_key_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12&\n\x13version_description\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12V\n\x17version_payload_entries\x18\x07 \x03(\x0b\x32+.yandex.cloud.lockbox.v1.PayloadEntryChangeB\x08\x82\xc8\x31\x04<=32\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x12_\n\x1epassword_payload_specification\x18\t \x01(\x0b\x32\x35.yandex.cloud.lockbox.v1.PasswordPayloadSpecificationH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x17\n\x15payload_specification\"=\n\x14\x43reateSecretMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"\xf5\x03\n\x13UpdateSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x17\n\x04name\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x85\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x38.yandex.cloud.lockbox.v1.UpdateSecretRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x12_\n\x1epassword_payload_specification\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.lockbox.v1.PasswordPayloadSpecificationH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x17\n\x15payload_specification\"7\n\x14UpdateSecretMetadata\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x13\x44\x65leteSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x14\x44\x65leteSecretMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\"8\n\x15\x41\x63tivateSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x16\x41\x63tivateSecretMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\":\n\x17\x44\x65\x61\x63tivateSecretRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x18\x44\x65\x61\x63tivateSecretMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\"\xc8\x01\n\x11\x41\x64\x64VersionRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\x0b\x64\x65scription\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12N\n\x0fpayload_entries\x18\x03 \x03(\x0b\x32+.yandex.cloud.lockbox.v1.PayloadEntryChangeB\x08\x82\xc8\x31\x04<=32\x12!\n\x0f\x62\x61se_version_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\";\n\x12\x41\x64\x64VersionMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"t\n\x13ListVersionsRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x14ListVersionsResponse\x12\x32\n\x08versions\x18\x01 \x03(\x0b\x32 .yandex.cloud.lockbox.v1.Version\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x99\x01\n!ScheduleVersionDestructionRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nversion_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x31\n\x0epending_period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"{\n\"ScheduleVersionDestructionMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12.\n\ndestroy_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"d\n\x1f\x43\x61ncelVersionDestructionRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nversion_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"I\n CancelVersionDestructionMetadata\x12\x11\n\tsecret_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"|\n\x1bListSecretOperationsRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x1cListSecretOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe9\x15\n\rSecretService\x12z\n\x03Get\x12).yandex.cloud.lockbox.v1.GetSecretRequest\x1a\x1f.yandex.cloud.lockbox.v1.Secret\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/lockbox/v1/secrets/{secret_id}\x12~\n\x04List\x12+.yandex.cloud.lockbox.v1.ListSecretsRequest\x1a,.yandex.cloud.lockbox.v1.ListSecretsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/lockbox/v1/secrets\x12\x9b\x01\n\x06\x43reate\x12,.yandex.cloud.lockbox.v1.CreateSecretRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x1e\n\x14\x43reateSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02\x18\"\x13/lockbox/v1/secrets:\x01*\x12\xa7\x01\n\x06Update\x12,.yandex.cloud.lockbox.v1.UpdateSecretRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2*\x1e\n\x14UpdateSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02$2\x1f/lockbox/v1/secrets/{secret_id}:\x01*\x12\xa4\x01\n\x06\x44\x65lete\x12,.yandex.cloud.lockbox.v1.DeleteSecretRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2*\x1e\n\x14\x44\x65leteSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02!*\x1f/lockbox/v1/secrets/{secret_id}\x12\xb3\x01\n\x08\x41\x63tivate\x12..yandex.cloud.lockbox.v1.ActivateSecretRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2* \n\x16\x41\x63tivateSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02*\"(/lockbox/v1/secrets/{secret_id}:activate\x12\xbb\x01\n\nDeactivate\x12\x30.yandex.cloud.lockbox.v1.DeactivateSecretRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\"\n\x18\x44\x65\x61\x63tivateSecretMetadata\x12\x06Secret\x82\xd3\xe4\x93\x02,\"*/lockbox/v1/secrets/{secret_id}:deactivate\x12\x9d\x01\n\x0cListVersions\x12,.yandex.cloud.lockbox.v1.ListVersionsRequest\x1a-.yandex.cloud.lockbox.v1.ListVersionsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/lockbox/v1/secrets/{secret_id}/versions\x12\xb3\x01\n\nAddVersion\x12*.yandex.cloud.lockbox.v1.AddVersionRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1d\n\x12\x41\x64\x64VersionMetadata\x12\x07Version\x82\xd3\xe4\x93\x02/\"*/lockbox/v1/secrets/{secret_id}:addVersion:\x01*\x12\xf3\x01\n\x1aScheduleVersionDestruction\x12:.yandex.cloud.lockbox.v1.ScheduleVersionDestructionRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*-\n\"ScheduleVersionDestructionMetadata\x12\x07Version\x82\xd3\xe4\x93\x02?\":/lockbox/v1/secrets/{secret_id}:scheduleVersionDestruction:\x01*\x12\xeb\x01\n\x18\x43\x61ncelVersionDestruction\x12\x38.yandex.cloud.lockbox.v1.CancelVersionDestructionRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2*+\n CancelVersionDestructionMetadata\x12\x07Version\x82\xd3\xe4\x93\x02=\"8/lockbox/v1/secrets/{secret_id}:cancelVersionDestruction:\x01*\x12\xb1\x01\n\x0eListOperations\x12\x34.yandex.cloud.lockbox.v1.ListSecretOperationsRequest\x1a\x35.yandex.cloud.lockbox.v1.ListSecretOperationsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/lockbox/v1/secrets/{secret_id}/operations\x12\xb3\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/lockbox/v1/secrets/{resource_id}:listAccessBindings\x12\xe2\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x38\"3/lockbox/v1/secrets/{resource_id}:setAccessBindings:\x01*\x12\xef\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;\"6/lockbox/v1/secrets/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockboxb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.lockbox.v1.secret_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockbox'
  _PAYLOADENTRYCHANGE.fields_by_name['key']._options = None
  _PAYLOADENTRYCHANGE.fields_by_name['key']._serialized_options = b'\350\3071\001\362\3071\023[-_./\\\\@0-9a-zA-Z]+\212\3101\005<=256'
  _PAYLOADENTRYCHANGE.fields_by_name['text_value']._options = None
  _PAYLOADENTRYCHANGE.fields_by_name['text_value']._serialized_options = b'\212\3101\007<=65536'
  _PAYLOADENTRYCHANGE.fields_by_name['binary_value']._options = None
  _PAYLOADENTRYCHANGE.fields_by_name['binary_value']._serialized_options = b'\212\3101\007<=65536'
  _GETSECRETREQUEST.fields_by_name['secret_id']._options = None
  _GETSECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSECRETSREQUEST.fields_by_name['folder_id']._options = None
  _LISTSECRETSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSECRETSREQUEST.fields_by_name['page_size']._options = None
  _LISTSECRETSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSECRETSREQUEST.fields_by_name['page_token']._options = None
  _LISTSECRETSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATESECRETREQUEST_LABELSENTRY._options = None
  _CREATESECRETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATESECRETREQUEST.fields_by_name['folder_id']._options = None
  _CREATESECRETREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESECRETREQUEST.fields_by_name['name']._options = None
  _CREATESECRETREQUEST.fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _CREATESECRETREQUEST.fields_by_name['description']._options = None
  _CREATESECRETREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _CREATESECRETREQUEST.fields_by_name['labels']._options = None
  _CREATESECRETREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _CREATESECRETREQUEST.fields_by_name['kms_key_id']._options = None
  _CREATESECRETREQUEST.fields_by_name['kms_key_id']._serialized_options = b'\212\3101\004<=50'
  _CREATESECRETREQUEST.fields_by_name['version_description']._options = None
  _CREATESECRETREQUEST.fields_by_name['version_description']._serialized_options = b'\212\3101\005<=256'
  _CREATESECRETREQUEST.fields_by_name['version_payload_entries']._options = None
  _CREATESECRETREQUEST.fields_by_name['version_payload_entries']._serialized_options = b'\202\3101\004<=32'
  _UPDATESECRETREQUEST_LABELSENTRY._options = None
  _UPDATESECRETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESECRETREQUEST.fields_by_name['secret_id']._options = None
  _UPDATESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESECRETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATESECRETREQUEST.fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _UPDATESECRETREQUEST.fields_by_name['name']._options = None
  _UPDATESECRETREQUEST.fields_by_name['name']._serialized_options = b'\212\3101\005<=100'
  _UPDATESECRETREQUEST.fields_by_name['description']._options = None
  _UPDATESECRETREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _UPDATESECRETREQUEST.fields_by_name['labels']._options = None
  _UPDATESECRETREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _UPDATESECRETMETADATA.fields_by_name['secret_id']._options = None
  _UPDATESECRETMETADATA.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETESECRETREQUEST.fields_by_name['secret_id']._options = None
  _DELETESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ACTIVATESECRETREQUEST.fields_by_name['secret_id']._options = None
  _ACTIVATESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DEACTIVATESECRETREQUEST.fields_by_name['secret_id']._options = None
  _DEACTIVATESECRETREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDVERSIONREQUEST.fields_by_name['secret_id']._options = None
  _ADDVERSIONREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDVERSIONREQUEST.fields_by_name['description']._options = None
  _ADDVERSIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _ADDVERSIONREQUEST.fields_by_name['payload_entries']._options = None
  _ADDVERSIONREQUEST.fields_by_name['payload_entries']._serialized_options = b'\202\3101\004<=32'
  _ADDVERSIONREQUEST.fields_by_name['base_version_id']._options = None
  _ADDVERSIONREQUEST.fields_by_name['base_version_id']._serialized_options = b'\212\3101\004<=50'
  _LISTVERSIONSREQUEST.fields_by_name['secret_id']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _SCHEDULEVERSIONDESTRUCTIONREQUEST.fields_by_name['secret_id']._options = None
  _SCHEDULEVERSIONDESTRUCTIONREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _SCHEDULEVERSIONDESTRUCTIONREQUEST.fields_by_name['version_id']._options = None
  _SCHEDULEVERSIONDESTRUCTIONREQUEST.fields_by_name['version_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CANCELVERSIONDESTRUCTIONREQUEST.fields_by_name['secret_id']._options = None
  _CANCELVERSIONDESTRUCTIONREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CANCELVERSIONDESTRUCTIONREQUEST.fields_by_name['version_id']._options = None
  _CANCELVERSIONDESTRUCTIONREQUEST.fields_by_name['version_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['secret_id']._options = None
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTSECRETOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _SECRETSERVICE.methods_by_name['Get']._options = None
  _SECRETSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/lockbox/v1/secrets/{secret_id}'
  _SECRETSERVICE.methods_by_name['List']._options = None
  _SECRETSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/lockbox/v1/secrets'
  _SECRETSERVICE.methods_by_name['Create']._options = None
  _SECRETSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateSecretMetadata\022\006Secret\202\323\344\223\002\030\"\023/lockbox/v1/secrets:\001*'
  _SECRETSERVICE.methods_by_name['Update']._options = None
  _SECRETSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateSecretMetadata\022\006Secret\202\323\344\223\002$2\037/lockbox/v1/secrets/{secret_id}:\001*'
  _SECRETSERVICE.methods_by_name['Delete']._options = None
  _SECRETSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*\036\n\024DeleteSecretMetadata\022\006Secret\202\323\344\223\002!*\037/lockbox/v1/secrets/{secret_id}'
  _SECRETSERVICE.methods_by_name['Activate']._options = None
  _SECRETSERVICE.methods_by_name['Activate']._serialized_options = b'\262\322* \n\026ActivateSecretMetadata\022\006Secret\202\323\344\223\002*\"(/lockbox/v1/secrets/{secret_id}:activate'
  _SECRETSERVICE.methods_by_name['Deactivate']._options = None
  _SECRETSERVICE.methods_by_name['Deactivate']._serialized_options = b'\262\322*\"\n\030DeactivateSecretMetadata\022\006Secret\202\323\344\223\002,\"*/lockbox/v1/secrets/{secret_id}:deactivate'
  _SECRETSERVICE.methods_by_name['ListVersions']._options = None
  _SECRETSERVICE.methods_by_name['ListVersions']._serialized_options = b'\202\323\344\223\002*\022(/lockbox/v1/secrets/{secret_id}/versions'
  _SECRETSERVICE.methods_by_name['AddVersion']._options = None
  _SECRETSERVICE.methods_by_name['AddVersion']._serialized_options = b'\262\322*\035\n\022AddVersionMetadata\022\007Version\202\323\344\223\002/\"*/lockbox/v1/secrets/{secret_id}:addVersion:\001*'
  _SECRETSERVICE.methods_by_name['ScheduleVersionDestruction']._options = None
  _SECRETSERVICE.methods_by_name['ScheduleVersionDestruction']._serialized_options = b'\262\322*-\n\"ScheduleVersionDestructionMetadata\022\007Version\202\323\344\223\002?\":/lockbox/v1/secrets/{secret_id}:scheduleVersionDestruction:\001*'
  _SECRETSERVICE.methods_by_name['CancelVersionDestruction']._options = None
  _SECRETSERVICE.methods_by_name['CancelVersionDestruction']._serialized_options = b'\262\322*+\n CancelVersionDestructionMetadata\022\007Version\202\323\344\223\002=\"8/lockbox/v1/secrets/{secret_id}:cancelVersionDestruction:\001*'
  _SECRETSERVICE.methods_by_name['ListOperations']._options = None
  _SECRETSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002,\022*/lockbox/v1/secrets/{secret_id}/operations'
  _SECRETSERVICE.methods_by_name['ListAccessBindings']._options = None
  _SECRETSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0026\0224/lockbox/v1/secrets/{resource_id}:listAccessBindings'
  _SECRETSERVICE.methods_by_name['SetAccessBindings']._options = None
  _SECRETSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0028\"3/lockbox/v1/secrets/{resource_id}:setAccessBindings:\001*'
  _SECRETSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _SECRETSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002;\"6/lockbox/v1/secrets/{resource_id}:updateAccessBindings:\001*'
  _globals['_PAYLOADENTRYCHANGE']._serialized_start=380
  _globals['_PAYLOADENTRYCHANGE']._serialized_end=532
  _globals['_GETSECRETREQUEST']._serialized_start=534
  _globals['_GETSECRETREQUEST']._serialized_end=585
  _globals['_LISTSECRETSREQUEST']._serialized_start=587
  _globals['_LISTSECRETSREQUEST']._serialized_end=702
  _globals['_LISTSECRETSRESPONSE']._serialized_start=704
  _globals['_LISTSECRETSRESPONSE']._serialized_end=800
  _globals['_CREATESECRETREQUEST']._serialized_start=803
  _globals['_CREATESECRETREQUEST']._serialized_end=1407
  _globals['_CREATESECRETREQUEST_LABELSENTRY']._serialized_start=1337
  _globals['_CREATESECRETREQUEST_LABELSENTRY']._serialized_end=1382
  _globals['_CREATESECRETMETADATA']._serialized_start=1409
  _globals['_CREATESECRETMETADATA']._serialized_end=1470
  _globals['_UPDATESECRETREQUEST']._serialized_start=1473
  _globals['_UPDATESECRETREQUEST']._serialized_end=1974
  _globals['_UPDATESECRETREQUEST_LABELSENTRY']._serialized_start=1337
  _globals['_UPDATESECRETREQUEST_LABELSENTRY']._serialized_end=1382
  _globals['_UPDATESECRETMETADATA']._serialized_start=1976
  _globals['_UPDATESECRETMETADATA']._serialized_end=2031
  _globals['_DELETESECRETREQUEST']._serialized_start=2033
  _globals['_DELETESECRETREQUEST']._serialized_end=2087
  _globals['_DELETESECRETMETADATA']._serialized_start=2089
  _globals['_DELETESECRETMETADATA']._serialized_end=2130
  _globals['_ACTIVATESECRETREQUEST']._serialized_start=2132
  _globals['_ACTIVATESECRETREQUEST']._serialized_end=2188
  _globals['_ACTIVATESECRETMETADATA']._serialized_start=2190
  _globals['_ACTIVATESECRETMETADATA']._serialized_end=2233
  _globals['_DEACTIVATESECRETREQUEST']._serialized_start=2235
  _globals['_DEACTIVATESECRETREQUEST']._serialized_end=2293
  _globals['_DEACTIVATESECRETMETADATA']._serialized_start=2295
  _globals['_DEACTIVATESECRETMETADATA']._serialized_end=2340
  _globals['_ADDVERSIONREQUEST']._serialized_start=2343
  _globals['_ADDVERSIONREQUEST']._serialized_end=2543
  _globals['_ADDVERSIONMETADATA']._serialized_start=2545
  _globals['_ADDVERSIONMETADATA']._serialized_end=2604
  _globals['_LISTVERSIONSREQUEST']._serialized_start=2606
  _globals['_LISTVERSIONSREQUEST']._serialized_end=2722
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=2724
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=2823
  _globals['_SCHEDULEVERSIONDESTRUCTIONREQUEST']._serialized_start=2826
  _globals['_SCHEDULEVERSIONDESTRUCTIONREQUEST']._serialized_end=2979
  _globals['_SCHEDULEVERSIONDESTRUCTIONMETADATA']._serialized_start=2981
  _globals['_SCHEDULEVERSIONDESTRUCTIONMETADATA']._serialized_end=3104
  _globals['_CANCELVERSIONDESTRUCTIONREQUEST']._serialized_start=3106
  _globals['_CANCELVERSIONDESTRUCTIONREQUEST']._serialized_end=3206
  _globals['_CANCELVERSIONDESTRUCTIONMETADATA']._serialized_start=3208
  _globals['_CANCELVERSIONDESTRUCTIONMETADATA']._serialized_end=3281
  _globals['_LISTSECRETOPERATIONSREQUEST']._serialized_start=3283
  _globals['_LISTSECRETOPERATIONSREQUEST']._serialized_end=3407
  _globals['_LISTSECRETOPERATIONSRESPONSE']._serialized_start=3409
  _globals['_LISTSECRETOPERATIONSRESPONSE']._serialized_end=3519
  _globals['_SECRETSERVICE']._serialized_start=3522
  _globals['_SECRETSERVICE']._serialized_end=6315
# @@protoc_insertion_point(module_scope)
