"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.serverless.workflows.v1.execution_pb2
import yandex.cloud.serverless.workflows.v1.history_entry_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class StartExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    @property
    def input(self) -> yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionInput:
        """Input for the Workflow execution"""

    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
        input: yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["input", b"input", "workflow_id", b"workflow_id"]) -> None: ...

global___StartExecutionRequest = StartExecutionRequest

@typing.final
class StartExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___StartExecutionResponse = StartExecutionResponse

@typing.final
class StopExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___StopExecutionRequest = StopExecutionRequest

@typing.final
class StopExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___StopExecutionResponse = StopExecutionResponse

@typing.final
class GetExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___GetExecutionRequest = GetExecutionRequest

@typing.final
class GetExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_FIELD_NUMBER: builtins.int
    @property
    def execution(self) -> yandex.cloud.serverless.workflows.v1.execution_pb2.Execution:
        """Workflow execution details."""

    def __init__(
        self,
        *,
        execution: yandex.cloud.serverless.workflows.v1.execution_pb2.Execution | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["execution", b"execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["execution", b"execution"]) -> None: ...

global___GetExecutionResponse = GetExecutionResponse

@typing.final
class GetExecutionHistoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """ID of the Workflow execution."""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["execution_id", b"execution_id"]) -> None: ...

global___GetExecutionHistoryRequest = GetExecutionHistoryRequest

@typing.final
class GetExecutionHistoryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def execution(self) -> yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionPreview:
        """Workflow execution details."""

    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.workflows.v1.history_entry_pb2.HistoryEntry]:
        """Workflow execution detailed history items."""

    def __init__(
        self,
        *,
        execution: yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionPreview | None = ...,
        entries: collections.abc.Iterable[yandex.cloud.serverless.workflows.v1.history_entry_pb2.HistoryEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["execution", b"execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["entries", b"entries", "execution", b"execution"]) -> None: ...

global___GetExecutionHistoryResponse = GetExecutionHistoryResponse

@typing.final
class ListExecutionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListExecutionsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListExecutionsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the following fields: status, started_at, finished_at.
    2. Operator: `=`, `<` or `>`.
    3. The value. Must be sting and match the regular expression `[+:\\.-a-z0-9]`.
    Examples of a filter: `status=ERROR`, `created_by=John.Doe`.
    """
    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "workflow_id", b"workflow_id"]) -> None: ...

global___ListExecutionsRequest = ListExecutionsRequest

@typing.final
class ListExecutionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListExecutionsRequest.page_size], use `next_page_token` as the value
    for the [ListExecutionsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def executions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionPreview]:
        """List of Workflow executions."""

    def __init__(
        self,
        *,
        executions: collections.abc.Iterable[yandex.cloud.serverless.workflows.v1.execution_pb2.ExecutionPreview] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["executions", b"executions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListExecutionsResponse = ListExecutionsResponse
