# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/snapshot_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/compute/v1/snapshot_schedule.proto\x12\x17yandex.cloud.compute.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x87\x05\n\x10SnapshotSchedule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x45\n\x06labels\x18\x06 \x03(\x0b\x32\x35.yandex.cloud.compute.v1.SnapshotSchedule.LabelsEntry\x12@\n\x06status\x18\x07 \x01(\x0e\x32\x30.yandex.cloud.compute.v1.SnapshotSchedule.Status\x12@\n\x0fschedule_policy\x18\x08 \x01(\x0b\x32\'.yandex.cloud.compute.v1.SchedulePolicy\x12\x35\n\x10retention_period\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x18\n\x0esnapshot_count\x18\n \x01(\x03H\x00\x12<\n\rsnapshot_spec\x18\x0b \x01(\x0b\x32%.yandex.cloud.compute.v1.SnapshotSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x42\x12\n\x10retention_policy\"R\n\x0eSchedulePolicy\x12,\n\x08start_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nexpression\x18\x02 \x01(\t\"\x95\x01\n\x0cSnapshotSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.yandex.cloud.compute.v1.SnapshotSpec.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.snapshot_schedule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _SNAPSHOTSCHEDULE_LABELSENTRY._options = None
  _SNAPSHOTSCHEDULE_LABELSENTRY._serialized_options = b'8\001'
  _SNAPSHOTSPEC_LABELSENTRY._options = None
  _SNAPSHOTSPEC_LABELSENTRY._serialized_options = b'8\001'
  _globals['_SNAPSHOTSCHEDULE']._serialized_start=142
  _globals['_SNAPSHOTSCHEDULE']._serialized_end=789
  _globals['_SNAPSHOTSCHEDULE_LABELSENTRY']._serialized_start=622
  _globals['_SNAPSHOTSCHEDULE_LABELSENTRY']._serialized_end=667
  _globals['_SNAPSHOTSCHEDULE_STATUS']._serialized_start=669
  _globals['_SNAPSHOTSCHEDULE_STATUS']._serialized_end=769
  _globals['_SCHEDULEPOLICY']._serialized_start=791
  _globals['_SCHEDULEPOLICY']._serialized_end=873
  _globals['_SNAPSHOTSPEC']._serialized_start=876
  _globals['_SNAPSHOTSPEC']._serialized_end=1025
  _globals['_SNAPSHOTSPEC_LABELSENTRY']._serialized_start=622
  _globals['_SNAPSHOTSPEC_LABELSENTRY']._serialized_end=667
# @@protoc_insertion_point(module_scope)
