# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/airflow/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.airflow.v1 import cluster_pb2 as yandex_dot_cloud_dot_airflow_dot_v1_dot_cluster__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/airflow/v1/cluster_service.proto\x12\x17yandex.cloud.airflow.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a%yandex/cloud/airflow/v1/cluster.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"c\n\x14ListClustersResponse\x12\x32\n\x08\x63lusters\x18\x01 \x03(\x0b\x32 .yandex.cloud.airflow.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x99\x05\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.airflow.v1.CreateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12<\n\x06\x63onfig\x18\x06 \x01(\x0b\x32&.yandex.cloud.airflow.v1.ClusterConfigB\x04\xe8\xc7\x31\x01\x12\x37\n\x07network\x18\x07 \x01(\x0b\x32&.yandex.cloud.airflow.v1.NetworkConfig\x12:\n\tcode_sync\x18\x08 \x01(\x0b\x32\'.yandex.cloud.airflow.v1.CodeSyncConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12$\n\x12service_account_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x37\n\x07logging\x18\x0b \x01(\x0b\x32&.yandex.cloud.airflow.v1.LoggingConfig\x12%\n\x0e\x61\x64min_password\x18\x0c \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x06\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xbc\x03\n\x17UpdateClusterConfigSpec\x12\x37\n\x07\x61irflow\x18\x02 \x01(\x0b\x32&.yandex.cloud.airflow.v1.AirflowConfig\x12;\n\twebserver\x18\x03 \x01(\x0b\x32(.yandex.cloud.airflow.v1.WebserverConfig\x12;\n\tscheduler\x18\x04 \x01(\x0b\x32(.yandex.cloud.airflow.v1.SchedulerConfig\x12;\n\ttriggerer\x18\x05 \x01(\x0b\x32(.yandex.cloud.airflow.v1.TriggererConfig\x12\x35\n\x06worker\x18\x06 \x01(\x0b\x32%.yandex.cloud.airflow.v1.WorkerConfig\x12;\n\x0c\x64\x65pendencies\x18\x07 \x01(\x0b\x32%.yandex.cloud.airflow.v1.Dependencies\x12\x37\n\x07lockbox\x18\x08 \x01(\x0b\x32&.yandex.cloud.airflow.v1.LockboxConfigJ\x04\x08\x01\x10\x02\"5\n\x17UpdateNetworkConfigSpec\x12\x1a\n\x12security_group_ids\x18\x01 \x03(\t\"\xb9\x05\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x86\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x39.yandex.cloud.airflow.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x45\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.airflow.v1.UpdateClusterConfigSpec\x12:\n\tcode_sync\x18\x07 \x01(\x0b\x32\'.yandex.cloud.airflow.v1.CodeSyncConfig\x12\x46\n\x0cnetwork_spec\x18\x08 \x01(\x0b\x32\x30.yandex.cloud.airflow.v1.UpdateNetworkConfigSpec\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x12$\n\x12service_account_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x37\n\x07logging\x18\x0b \x01(\x0b\x32&.yandex.cloud.airflow.v1.LoggingConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xf2\n\n\x0e\x43lusterService\x12\x86\x01\n\x03Get\x12*.yandex.cloud.airflow.v1.GetClusterRequest\x1a .yandex.cloud.airflow.v1.Cluster\"1\x82\xd3\xe4\x93\x02+\x12)/managed-airflow/v1/clusters/{cluster_id}\x12\x89\x01\n\x04List\x12,.yandex.cloud.airflow.v1.ListClustersRequest\x1a-.yandex.cloud.airflow.v1.ListClustersResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/managed-airflow/v1/clusters\x12\xa7\x01\n\x06\x43reate\x12-.yandex.cloud.airflow.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02!\"\x1c/managed-airflow/v1/clusters:\x01*\x12\xb4\x01\n\x06Update\x12-.yandex.cloud.airflow.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02.2)/managed-airflow/v1/clusters/{cluster_id}:\x01*\x12\xbf\x01\n\x06\x44\x65lete\x12-.yandex.cloud.airflow.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02+*)/managed-airflow/v1/clusters/{cluster_id}\x12\xb4\x01\n\x05Start\x12,.yandex.cloud.airflow.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\"//managed-airflow/v1/clusters/{cluster_id}:start\x12\xb0\x01\n\x04Stop\x12+.yandex.cloud.airflow.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x30\"./managed-airflow/v1/clusters/{cluster_id}:stop\x12\xbd\x01\n\x0eListOperations\x12\x35.yandex.cloud.airflow.v1.ListClusterOperationsRequest\x1a\x36.yandex.cloud.airflow.v1.ListClusterOperationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-airflow/v1/clusters/{cluster_id}/operationsBb\n\x1byandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflowb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.airflow.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.airflow.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/airflow/v1;airflow'
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATECLUSTERREQUEST_LABELSENTRY._options = None
  _CREATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['name']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CREATECLUSTERREQUEST.fields_by_name['description']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _CREATECLUSTERREQUEST.fields_by_name['config']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['config']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['service_account_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['admin_password']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['admin_password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _UPDATECLUSTERREQUEST_LABELSENTRY._options = None
  _UPDATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECLUSTERREQUEST.fields_by_name['service_account_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CLUSTERSERVICE.methods_by_name['Get']._options = None
  _CLUSTERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/managed-airflow/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['List']._options = None
  _CLUSTERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\036\022\034/managed-airflow/v1/clusters'
  _CLUSTERSERVICE.methods_by_name['Create']._options = None
  _CLUSTERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002!\"\034/managed-airflow/v1/clusters:\001*'
  _CLUSTERSERVICE.methods_by_name['Update']._options = None
  _CLUSTERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002.2)/managed-airflow/v1/clusters/{cluster_id}:\001*'
  _CLUSTERSERVICE.methods_by_name['Delete']._options = None
  _CLUSTERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002+*)/managed-airflow/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['Start']._options = None
  _CLUSTERSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0021\"//managed-airflow/v1/clusters/{cluster_id}:start'
  _CLUSTERSERVICE.methods_by_name['Stop']._options = None
  _CLUSTERSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0020\"./managed-airflow/v1/clusters/{cluster_id}:stop'
  _CLUSTERSERVICE.methods_by_name['ListOperations']._options = None
  _CLUSTERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0026\0224/managed-airflow/v1/clusters/{cluster_id}/operations'
  _globals['_GETCLUSTERREQUEST']._serialized_start=282
  _globals['_GETCLUSTERREQUEST']._serialized_end=335
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=338
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=482
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=484
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=583
  _globals['_CREATECLUSTERREQUEST']._serialized_start=586
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1251
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1200
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1245
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1253
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1296
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_start=1299
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_end=1743
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_start=1745
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_end=1798
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1801
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2498
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1200
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1245
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2500
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2543
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2545
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2601
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2603
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2646
  _globals['_STARTCLUSTERREQUEST']._serialized_start=2648
  _globals['_STARTCLUSTERREQUEST']._serialized_end=2703
  _globals['_STARTCLUSTERMETADATA']._serialized_start=2705
  _globals['_STARTCLUSTERMETADATA']._serialized_end=2747
  _globals['_STOPCLUSTERREQUEST']._serialized_start=2749
  _globals['_STOPCLUSTERREQUEST']._serialized_end=2803
  _globals['_STOPCLUSTERMETADATA']._serialized_start=2805
  _globals['_STOPCLUSTERMETADATA']._serialized_end=2846
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=2848
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=2974
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=2976
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=3087
  _globals['_CLUSTERSERVICE']._serialized_start=3090
  _globals['_CLUSTERSERVICE']._serialized_end=4484
# @@protoc_insertion_point(module_scope)
