"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.cdn.v1.raw_logs_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ActivateRawLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource to switch logs storage for.."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id", "settings", b"settings"]) -> None: ...

global___ActivateRawLogsRequest = ActivateRawLogsRequest

@typing.final
class ActivateRawLogsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of resource with activated raw logs."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___ActivateRawLogsMetadata = ActivateRawLogsMetadata

@typing.final
class ActivateRawLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType
    """Raw logs status."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["settings", b"settings", "status", b"status"]) -> None: ...

global___ActivateRawLogsResponse = ActivateRawLogsResponse

@typing.final
class DeactivateRawLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource to deactivate Raw Logs for."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___DeactivateRawLogsRequest = DeactivateRawLogsRequest

@typing.final
class DeactivateRawLogsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___DeactivateRawLogsMetadata = DeactivateRawLogsMetadata

@typing.final
class GetRawLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource to request status and settings."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___GetRawLogsRequest = GetRawLogsRequest

@typing.final
class GetRawLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType
    """Raw logs status."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["settings", b"settings", "status", b"status"]) -> None: ...

global___GetRawLogsResponse = GetRawLogsResponse

@typing.final
class UpdateRawLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id", "settings", b"settings"]) -> None: ...

global___UpdateRawLogsRequest = UpdateRawLogsRequest

@typing.final
class UpdateRawLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType
    """Raw logs status."""
    @property
    def settings(self) -> yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings:
        """Raw logs settings."""

    def __init__(
        self,
        *,
        status: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsStatus.ValueType = ...,
        settings: yandex.cloud.cdn.v1.raw_logs_pb2.RawLogsSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["settings", b"settings", "status", b"status"]) -> None: ...

global___UpdateRawLogsResponse = UpdateRawLogsResponse

@typing.final
class UpdateRawLogsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_ID_FIELD_NUMBER: builtins.int
    resource_id: builtins.str
    """ID of CDN resource."""
    def __init__(
        self,
        *,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_id", b"resource_id"]) -> None: ...

global___UpdateRawLogsMetadata = UpdateRawLogsMetadata
