# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/loadtesting/agent/v1/test.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x88\x08\n\x04Test\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x43\n\x06labels\x18\x05 \x03(\x0b\x32\x33.yandex.cloud.loadtesting.agent.v1.Test.LabelsEntry\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\tgenerator\x18\n \x01(\x0e\x32\x31.yandex.cloud.loadtesting.agent.v1.Test.Generator\x12\x19\n\x11\x61gent_instance_id\x18\x0b \x01(\t\x12\x16\n\x0etarget_address\x18\x0c \x01(\t\x12\x13\n\x0btarget_port\x18\r \x01(\x03\x12\x16\n\x0etarget_version\x18\x0e \x01(\t\x12\x0e\n\x06\x63onfig\x18\x0f \x01(\t\x12\x13\n\tammo_urls\x18\x10 \x01(\tH\x00\x12\x11\n\x07\x61mmo_id\x18\x11 \x01(\tH\x00\x12\r\n\x05\x63\x61ses\x18\x12 \x03(\t\x12>\n\x06status\x18\x13 \x01(\x0e\x32..yandex.cloud.loadtesting.agent.v1.Test.Status\x12\x0e\n\x06\x65rrors\x18\x14 \x03(\t\x12\x10\n\x08\x66\x61vorite\x18\x15 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe3\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\r\n\tINITIATED\x10\x02\x12\r\n\tPREPARING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\r\n\tFINISHING\x10\x05\x12\x08\n\x04\x44ONE\x10\x06\x12\x13\n\x0fPOST_PROCESSING\x10\x07\x12\n\n\x06\x46\x41ILED\x10\x08\x12\x0c\n\x08STOPPING\x10\t\x12\x0b\n\x07STOPPED\x10\n\x12\x0f\n\x0b\x41UTOSTOPPED\x10\x0b\x12\x0b\n\x07WAITING\x10\x0c\x12\x0c\n\x08\x44\x45LETING\x10\r\x12\x08\n\x04LOST\x10\x0e\"L\n\tGenerator\x12\x19\n\x15GENERATOR_UNSPECIFIED\x10\x00\x12\x0b\n\x07PANDORA\x10\x01\x12\x0b\n\x07PHANTOM\x10\x02\x12\n\n\x06JMETER\x10\x03\x42\x06\n\x04\x61mmoBt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.test_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _TEST_LABELSENTRY._options = None
  _TEST_LABELSENTRY._serialized_options = b'8\001'
  _globals['_TEST']._serialized_start=117
  _globals['_TEST']._serialized_end=1149
  _globals['_TEST_LABELSENTRY']._serialized_start=788
  _globals['_TEST_LABELSENTRY']._serialized_end=833
  _globals['_TEST_STATUS']._serialized_start=836
  _globals['_TEST_STATUS']._serialized_end=1063
  _globals['_TEST_GENERATOR']._serialized_start=1065
  _globals['_TEST_GENERATOR']._serialized_end=1141
# @@protoc_insertion_point(module_scope)
