# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/scan_policy_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import scan_policy_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scan__policy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/containerregistry/v1/scan_policy_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a\x33yandex/cloud/containerregistry/v1/scan_policy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\"<\n\x14GetScanPolicyRequest\x12$\n\x0escan_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"C\n\x1eGetScanPolicyByRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xca\x01\n\x17\x43reateScanPolicyRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12;\n\x05rules\x18\x04 \x01(\x0b\x32,.yandex.cloud.containerregistry.v1.ScanRules\"\xfe\x01\n\x17UpdateScanPolicyRequest\x12$\n\x0escan_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12;\n\x05rules\x18\x05 \x01(\x0b\x32,.yandex.cloud.containerregistry.v1.ScanRules\"?\n\x17\x44\x65leteScanPolicyRequest\x12$\n\x0escan_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"2\n\x18\x43reateScanPolicyMetadata\x12\x16\n\x0escan_policy_id\x18\x01 \x01(\t\"2\n\x18UpdateScanPolicyMetadata\x12\x16\n\x0escan_policy_id\x18\x01 \x01(\t\"2\n\x18\x44\x65leteScanPolicyMetadata\x12\x16\n\x0escan_policy_id\x18\x01 \x01(\t2\x81\x08\n\x11ScanPolicyService\x12\xab\x01\n\x03Get\x12\x37.yandex.cloud.containerregistry.v1.GetScanPolicyRequest\x1a-.yandex.cloud.containerregistry.v1.ScanPolicy\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/container-registry/v1/scanPolicies/{scan_policy_id}\x12\xc7\x01\n\rGetByRegistry\x12\x41.yandex.cloud.containerregistry.v1.GetScanPolicyByRegistryRequest\x1a-.yandex.cloud.containerregistry.v1.ScanPolicy\"D\x82\xd3\xe4\x93\x02>\x12</container-registry/v1/scanPolicies/{registry_id}:byRegistry\x12\xc1\x01\n\x06\x43reate\x12:.yandex.cloud.containerregistry.v1.CreateScanPolicyRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*&\n\x18\x43reateScanPolicyMetadata\x12\nScanPolicy\x82\xd3\xe4\x93\x02(\"#/container-registry/v1/scanPolicies:\x01*\x12\xd2\x01\n\x06Update\x12:.yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*&\n\x18UpdateScanPolicyMetadata\x12\nScanPolicy\x82\xd3\xe4\x93\x02\x39\x32\x34/container-registry/v1/scanPolicies/{scan_policy_id}:\x01*\x12\xda\x01\n\x06\x44\x65lete\x12:.yandex.cloud.containerregistry.v1.DeleteScanPolicyRequest\x1a!.yandex.cloud.operation.Operation\"q\xb2\xd2*1\n\x18\x44\x65leteScanPolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/container-registry/v1/scanPolicies/{scan_policy_id}B\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _GETSCANPOLICYREQUEST.fields_by_name['scan_policy_id']._options = None
  _GETSCANPOLICYREQUEST.fields_by_name['scan_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETSCANPOLICYBYREGISTRYREQUEST.fields_by_name['registry_id']._options = None
  _GETSCANPOLICYBYREGISTRYREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESCANPOLICYREQUEST.fields_by_name['registry_id']._options = None
  _CREATESCANPOLICYREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESCANPOLICYREQUEST.fields_by_name['name']._options = None
  _CREATESCANPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATESCANPOLICYREQUEST.fields_by_name['description']._options = None
  _CREATESCANPOLICYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._options = None
  _UPDATESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESCANPOLICYREQUEST.fields_by_name['name']._options = None
  _UPDATESCANPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATESCANPOLICYREQUEST.fields_by_name['description']._options = None
  _UPDATESCANPOLICYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _DELETESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._options = None
  _DELETESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _SCANPOLICYSERVICE.methods_by_name['Get']._options = None
  _SCANPOLICYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/container-registry/v1/scanPolicies/{scan_policy_id}'
  _SCANPOLICYSERVICE.methods_by_name['GetByRegistry']._options = None
  _SCANPOLICYSERVICE.methods_by_name['GetByRegistry']._serialized_options = b'\202\323\344\223\002>\022</container-registry/v1/scanPolicies/{registry_id}:byRegistry'
  _SCANPOLICYSERVICE.methods_by_name['Create']._options = None
  _SCANPOLICYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateScanPolicyMetadata\022\nScanPolicy\202\323\344\223\002(\"#/container-registry/v1/scanPolicies:\001*'
  _SCANPOLICYSERVICE.methods_by_name['Update']._options = None
  _SCANPOLICYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateScanPolicyMetadata\022\nScanPolicy\202\323\344\223\002924/container-registry/v1/scanPolicies/{scan_policy_id}:\001*'
  _SCANPOLICYSERVICE.methods_by_name['Delete']._options = None
  _SCANPOLICYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteScanPolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/container-registry/v1/scanPolicies/{scan_policy_id}'
  _globals['_GETSCANPOLICYREQUEST']._serialized_start=320
  _globals['_GETSCANPOLICYREQUEST']._serialized_end=380
  _globals['_GETSCANPOLICYBYREGISTRYREQUEST']._serialized_start=382
  _globals['_GETSCANPOLICYBYREGISTRYREQUEST']._serialized_end=449
  _globals['_CREATESCANPOLICYREQUEST']._serialized_start=452
  _globals['_CREATESCANPOLICYREQUEST']._serialized_end=654
  _globals['_UPDATESCANPOLICYREQUEST']._serialized_start=657
  _globals['_UPDATESCANPOLICYREQUEST']._serialized_end=911
  _globals['_DELETESCANPOLICYREQUEST']._serialized_start=913
  _globals['_DELETESCANPOLICYREQUEST']._serialized_end=976
  _globals['_CREATESCANPOLICYMETADATA']._serialized_start=978
  _globals['_CREATESCANPOLICYMETADATA']._serialized_end=1028
  _globals['_UPDATESCANPOLICYMETADATA']._serialized_start=1030
  _globals['_UPDATESCANPOLICYMETADATA']._serialized_end=1080
  _globals['_DELETESCANPOLICYMETADATA']._serialized_start=1082
  _globals['_DELETESCANPOLICYMETADATA']._serialized_end=1132
  _globals['_SCANPOLICYSERVICE']._serialized_start=1135
  _globals['_SCANPOLICYSERVICE']._serialized_end=2160
# @@protoc_insertion_point(module_scope)
