"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PutEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to put event."""
    body: builtins.str
    """Event body."""
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        body: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "bus_id", b"bus_id"]) -> None: ...

global___PutEventRequest = PutEventRequest
