"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Customer(google.protobuf.message.Message):
    """A Customer resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the customer."""
    billing_account_id: builtins.str
    """ID of the [yandex.cloud.billing.v1.BillingAccount] assigned to the customer."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        billing_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "id", b"id"]) -> None: ...

global___Customer = Customer

@typing.final
class CustomerPerson(google.protobuf.message.Message):
    """Person of the customer. Contains legal information."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    LONGNAME_FIELD_NUMBER: builtins.int
    PHONE_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    POST_CODE_FIELD_NUMBER: builtins.int
    POST_ADDRESS_FIELD_NUMBER: builtins.int
    LEGAL_ADDRESS_FIELD_NUMBER: builtins.int
    TIN_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Optional. Name of the person.

    String length is not limited.
    """
    longname: builtins.str
    """Optional. Long name of the person.

    String length is not limited.
    """
    phone: builtins.str
    """Optional. Phone of the person.

    Must be a valid telephone number or a valid [phoneword](https://en.m.wikipedia.org/wiki/Phoneword).
    """
    email: builtins.str
    """Optional. Email of the person.

    Must be a valid [email address](https://en.wikipedia.org/wiki/Email_address).
    """
    post_code: builtins.str
    """Optional. Post code of the person.

    String length is not limited.
    """
    post_address: builtins.str
    """Optional. Post address of the person.

    String length is not limited.
    """
    legal_address: builtins.str
    """Optional. Legal address of the person.

    String length is not limited.
    """
    tin: builtins.str
    """Optional. Tax identification number of the person.

    String length is not limited.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        longname: builtins.str = ...,
        phone: builtins.str = ...,
        email: builtins.str = ...,
        post_code: builtins.str = ...,
        post_address: builtins.str = ...,
        legal_address: builtins.str = ...,
        tin: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["email", b"email", "legal_address", b"legal_address", "longname", b"longname", "name", b"name", "phone", b"phone", "post_address", b"post_address", "post_code", b"post_code", "tin", b"tin"]) -> None: ...

global___CustomerPerson = CustomerPerson
