# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/instance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.compute.v1 import hardware_generation_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_hardware__generation__pb2
from yandex.cloud.compute.v1 import maintenance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/compute/v1/instance.proto\x12\x17yandex.cloud.compute.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31yandex/cloud/compute/v1/hardware_generation.proto\x1a)yandex/cloud/compute/v1/maintenance.proto\"\xae\r\n\x08Instance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12=\n\x06labels\x18\x06 \x03(\x0b\x32-.yandex.cloud.compute.v1.Instance.LabelsEntry\x12\x0f\n\x07zone_id\x18\x07 \x01(\t\x12\x13\n\x0bplatform_id\x18\x08 \x01(\t\x12\x35\n\tresources\x18\t \x01(\x0b\x32\".yandex.cloud.compute.v1.Resources\x12\x38\n\x06status\x18\n \x01(\x0e\x32(.yandex.cloud.compute.v1.Instance.Status\x12\x41\n\x08metadata\x18\x0b \x03(\x0b\x32/.yandex.cloud.compute.v1.Instance.MetadataEntry\x12\x42\n\x10metadata_options\x18\x17 \x01(\x0b\x32(.yandex.cloud.compute.v1.MetadataOptions\x12\x38\n\tboot_disk\x18\x0c \x01(\x0b\x32%.yandex.cloud.compute.v1.AttachedDisk\x12>\n\x0fsecondary_disks\x18\r \x03(\x0b\x32%.yandex.cloud.compute.v1.AttachedDisk\x12?\n\x0blocal_disks\x18\x16 \x03(\x0b\x32*.yandex.cloud.compute.v1.AttachedLocalDisk\x12@\n\x0b\x66ilesystems\x18\x15 \x03(\x0b\x32+.yandex.cloud.compute.v1.AttachedFilesystem\x12\x45\n\x12network_interfaces\x18\x0e \x03(\x0b\x32).yandex.cloud.compute.v1.NetworkInterface\x12I\n\x14serial_port_settings\x18\x18 \x01(\x0b\x32+.yandex.cloud.compute.v1.SerialPortSettings\x12:\n\x0cgpu_settings\x18\x1a \x01(\x0b\x32$.yandex.cloud.compute.v1.GpuSettings\x12\x0c\n\x04\x66qdn\x18\x10 \x01(\t\x12\x44\n\x11scheduling_policy\x18\x11 \x01(\x0b\x32).yandex.cloud.compute.v1.SchedulingPolicy\x12\x1a\n\x12service_account_id\x18\x12 \x01(\t\x12\x42\n\x10network_settings\x18\x13 \x01(\x0b\x32(.yandex.cloud.compute.v1.NetworkSettings\x12\x42\n\x10placement_policy\x18\x14 \x01(\x0b\x32(.yandex.cloud.compute.v1.PlacementPolicy\x12\x15\n\rhost_group_id\x18\x1b \x01(\t\x12\x0f\n\x07host_id\x18\x1c \x01(\t\x12\x46\n\x12maintenance_policy\x18\x1d \x01(\x0e\x32*.yandex.cloud.compute.v1.MaintenancePolicy\x12;\n\x18maintenance_grace_period\x18\x1e \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\x13hardware_generation\x18\x1f \x01(\x0b\x32+.yandex.cloud.compute.v1.HardwareGeneration\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08STOPPING\x10\x03\x12\x0b\n\x07STOPPED\x10\x04\x12\x0c\n\x08STARTING\x10\x05\x12\x0e\n\nRESTARTING\x10\x06\x12\x0c\n\x08UPDATING\x10\x07\x12\t\n\x05\x45RROR\x10\x08\x12\x0b\n\x07\x43RASHED\x10\t\x12\x0c\n\x08\x44\x45LETING\x10\nJ\x04\x08\x0f\x10\x10J\x04\x08\x19\x10\x1a\"O\n\tResources\x12\x0e\n\x06memory\x18\x01 \x01(\x03\x12\r\n\x05\x63ores\x18\x02 \x01(\x03\x12\x15\n\rcore_fraction\x18\x03 \x01(\x03\x12\x0c\n\x04gpus\x18\x04 \x01(\x03\"\xc0\x01\n\x0c\x41ttachedDisk\x12\x38\n\x04mode\x18\x01 \x01(\x0e\x32*.yandex.cloud.compute.v1.AttachedDisk.Mode\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x13\n\x0b\x61uto_delete\x18\x03 \x01(\x08\x12\x0f\n\x07\x64isk_id\x18\x04 \x01(\t\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\"6\n\x11\x41ttachedLocalDisk\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\"\xbd\x01\n\x12\x41ttachedFilesystem\x12>\n\x04mode\x18\x01 \x01(\x0e\x32\x30.yandex.cloud.compute.v1.AttachedFilesystem.Mode\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x15\n\rfilesystem_id\x18\x03 \x01(\t\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\"\xef\x01\n\x10NetworkInterface\x12\r\n\x05index\x18\x01 \x01(\t\x12\x13\n\x0bmac_address\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\x12\x43\n\x12primary_v4_address\x18\x04 \x01(\x0b\x32\'.yandex.cloud.compute.v1.PrimaryAddress\x12\x43\n\x12primary_v6_address\x18\x05 \x01(\x0b\x32\'.yandex.cloud.compute.v1.PrimaryAddress\x12\x1a\n\x12security_group_ids\x18\x06 \x03(\t\"\x98\x01\n\x0ePrimaryAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12<\n\x0eone_to_one_nat\x18\x02 \x01(\x0b\x32$.yandex.cloud.compute.v1.OneToOneNat\x12\x37\n\x0b\x64ns_records\x18\x03 \x03(\x0b\x32\".yandex.cloud.compute.v1.DnsRecord\"\x8f\x01\n\x0bOneToOneNat\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x36\n\nip_version\x18\x02 \x01(\x0e\x32\".yandex.cloud.compute.v1.IpVersion\x12\x37\n\x0b\x64ns_records\x18\x03 \x03(\x0b\x32\".yandex.cloud.compute.v1.DnsRecord\"H\n\tDnsRecord\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x0b\n\x03ttl\x18\x03 \x01(\x03\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"\'\n\x10SchedulingPolicy\x12\x13\n\x0bpreemptible\x18\x01 \x01(\x08\"\xae\x01\n\x0fNetworkSettings\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.yandex.cloud.compute.v1.NetworkSettings.Type\"^\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x18\n\x14SOFTWARE_ACCELERATED\x10\x02\x12\x18\n\x14HARDWARE_ACCELERATED\x10\x03\"%\n\x0bGpuSettings\x12\x16\n\x0egpu_cluster_id\x18\x01 \x01(\t\"\xe4\x02\n\x0fPlacementPolicy\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12V\n\x13host_affinity_rules\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.compute.v1.PlacementPolicy.HostAffinityRule\x12!\n\x19placement_group_partition\x18\x03 \x01(\x03\x1a\xb9\x01\n\x10HostAffinityRule\x12\x0b\n\x03key\x18\x01 \x01(\t\x12N\n\x02op\x18\x02 \x01(\x0e\x32\x42.yandex.cloud.compute.v1.PlacementPolicy.HostAffinityRule.Operator\x12\x0e\n\x06values\x18\x03 \x03(\t\"8\n\x08Operator\x12\x18\n\x14OPERATOR_UNSPECIFIED\x10\x00\x12\x06\n\x02IN\x10\x01\x12\n\n\x06NOT_IN\x10\x02\"\xa1\x02\n\x0fMetadataOptions\x12\x42\n\x11gce_http_endpoint\x18\x01 \x01(\x0e\x32\'.yandex.cloud.compute.v1.MetadataOption\x12\x45\n\x14\x61ws_v1_http_endpoint\x18\x02 \x01(\x0e\x32\'.yandex.cloud.compute.v1.MetadataOption\x12?\n\x0egce_http_token\x18\x03 \x01(\x0e\x32\'.yandex.cloud.compute.v1.MetadataOption\x12\x42\n\x11\x61ws_v1_http_token\x18\x04 \x01(\x0e\x32\'.yandex.cloud.compute.v1.MetadataOption\"\xc9\x01\n\x12SerialPortSettings\x12W\n\x11ssh_authorization\x18\x01 \x01(\x0e\x32<.yandex.cloud.compute.v1.SerialPortSettings.SSHAuthorization\"Z\n\x10SSHAuthorization\x12!\n\x1dSSH_AUTHORIZATION_UNSPECIFIED\x10\x00\x12\x15\n\x11INSTANCE_METADATA\x10\x01\x12\x0c\n\x08OS_LOGIN\x10\x02*;\n\tIpVersion\x12\x1a\n\x16IP_VERSION_UNSPECIFIED\x10\x00\x12\x08\n\x04IPV4\x10\x01\x12\x08\n\x04IPV6\x10\x02*L\n\x0eMetadataOption\x12\x1f\n\x1bMETADATA_OPTION_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.instance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _INSTANCE_LABELSENTRY._options = None
  _INSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _INSTANCE_METADATAENTRY._options = None
  _INSTANCE_METADATAENTRY._serialized_options = b'8\001'
  _globals['_IPVERSION']._serialized_start=4192
  _globals['_IPVERSION']._serialized_end=4251
  _globals['_METADATAOPTION']._serialized_start=4253
  _globals['_METADATAOPTION']._serialized_end=4329
  _globals['_INSTANCE']._serialized_start=227
  _globals['_INSTANCE']._serialized_end=1937
  _globals['_INSTANCE_LABELSENTRY']._serialized_start=1656
  _globals['_INSTANCE_LABELSENTRY']._serialized_end=1701
  _globals['_INSTANCE_METADATAENTRY']._serialized_start=1703
  _globals['_INSTANCE_METADATAENTRY']._serialized_end=1750
  _globals['_INSTANCE_STATUS']._serialized_start=1753
  _globals['_INSTANCE_STATUS']._serialized_end=1925
  _globals['_RESOURCES']._serialized_start=1939
  _globals['_RESOURCES']._serialized_end=2018
  _globals['_ATTACHEDDISK']._serialized_start=2021
  _globals['_ATTACHEDDISK']._serialized_end=2213
  _globals['_ATTACHEDDISK_MODE']._serialized_start=2154
  _globals['_ATTACHEDDISK_MODE']._serialized_end=2213
  _globals['_ATTACHEDLOCALDISK']._serialized_start=2215
  _globals['_ATTACHEDLOCALDISK']._serialized_end=2269
  _globals['_ATTACHEDFILESYSTEM']._serialized_start=2272
  _globals['_ATTACHEDFILESYSTEM']._serialized_end=2461
  _globals['_ATTACHEDFILESYSTEM_MODE']._serialized_start=2154
  _globals['_ATTACHEDFILESYSTEM_MODE']._serialized_end=2213
  _globals['_NETWORKINTERFACE']._serialized_start=2464
  _globals['_NETWORKINTERFACE']._serialized_end=2703
  _globals['_PRIMARYADDRESS']._serialized_start=2706
  _globals['_PRIMARYADDRESS']._serialized_end=2858
  _globals['_ONETOONENAT']._serialized_start=2861
  _globals['_ONETOONENAT']._serialized_end=3004
  _globals['_DNSRECORD']._serialized_start=3006
  _globals['_DNSRECORD']._serialized_end=3078
  _globals['_SCHEDULINGPOLICY']._serialized_start=3080
  _globals['_SCHEDULINGPOLICY']._serialized_end=3119
  _globals['_NETWORKSETTINGS']._serialized_start=3122
  _globals['_NETWORKSETTINGS']._serialized_end=3296
  _globals['_NETWORKSETTINGS_TYPE']._serialized_start=3202
  _globals['_NETWORKSETTINGS_TYPE']._serialized_end=3296
  _globals['_GPUSETTINGS']._serialized_start=3298
  _globals['_GPUSETTINGS']._serialized_end=3335
  _globals['_PLACEMENTPOLICY']._serialized_start=3338
  _globals['_PLACEMENTPOLICY']._serialized_end=3694
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE']._serialized_start=3509
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE']._serialized_end=3694
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR']._serialized_start=3638
  _globals['_PLACEMENTPOLICY_HOSTAFFINITYRULE_OPERATOR']._serialized_end=3694
  _globals['_METADATAOPTIONS']._serialized_start=3697
  _globals['_METADATAOPTIONS']._serialized_end=3986
  _globals['_SERIALPORTSETTINGS']._serialized_start=3989
  _globals['_SERIALPORTSETTINGS']._serialized_end=4190
  _globals['_SERIALPORTSETTINGS_SSHAUTHORIZATION']._serialized_start=4100
  _globals['_SERIALPORTSETTINGS_SSHAUTHORIZATION']._serialized_end=4190
# @@protoc_insertion_point(module_scope)
