"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Extension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the extension."""
    id: builtins.str
    """Unique ID of the extension."""
    cluster_id: builtins.str
    """ID of the Elasticsearch cluster the extension belongs to."""
    version: builtins.int
    """Version of the extension."""
    active: builtins.bool
    """The flag shows whether the extension is active."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        version: builtins.int = ...,
        active: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["active", b"active", "cluster_id", b"cluster_id", "id", b"id", "name", b"name", "version", b"version"]) -> None: ...

global___Extension = Extension

@typing.final
class ExtensionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the extension."""
    uri: builtins.str
    """URI of the zip archive to create the new extension from. Currently only supports links that are stored in Object Storage."""
    disabled: builtins.bool
    """The flag shows whether to create the extension in disabled state."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uri: builtins.str = ...,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disabled", b"disabled", "name", b"name", "uri", b"uri"]) -> None: ...

global___ExtensionSpec = ExtensionSpec
