# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/address_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.vpc.v1 import address_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_address__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/vpc/v1/address_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a!yandex/cloud/vpc/v1/address.proto\"5\n\x11GetAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"F\n\x18GetAddressByValueRequest\x12\x1f\n\x15\x65xternal_ipv4_address\x18\x01 \x01(\tH\x00\x42\t\n\x07\x61\x64\x64ress\"\x85\x01\n\x14ListAddressesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"a\n\x15ListAddressesResponse\x12/\n\taddresses\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.vpc.v1.Address\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x04\n\x14\x43reateAddressRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x04name\x18\x02 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x82\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.CreateAddressRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12R\n\x1a\x65xternal_ipv4_address_spec\x18\x05 \x01(\x0b\x32,.yandex.cloud.vpc.v1.ExternalIpv4AddressSpecH\x00\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12<\n\x10\x64ns_record_specs\x18\x0b \x03(\x0b\x32\".yandex.cloud.vpc.v1.DnsRecordSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0c\x61\x64\x64ress_specJ\x04\x08\x06\x10\n\"{\n\x17\x45xternalIpv4AddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07zone_id\x18\x02 \x01(\t\x12>\n\x0crequirements\x18\x03 \x01(\x0b\x32(.yandex.cloud.vpc.v1.AddressRequirements\"k\n\rDnsRecordSpec\x12\x12\n\x04\x66qdn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x0b\x64ns_zone_id\x18\x02 \x01(\tB\n\xe8\xc7\x31\x01\x8a\xc8\x31\x02\x32\x30\x12\x18\n\x03ttl\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"+\n\x15\x43reateAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t\"\xe8\x03\n\x14UpdateAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x04name\x18\x03 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x82\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.UpdateAddressRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x10\n\x08reserved\x18\x06 \x01(\x08\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x12<\n\x10\x64ns_record_specs\x18\x08 \x03(\x0b\x32\".yandex.cloud.vpc.v1.DnsRecordSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t\"~\n\x1cListAddressOperationsRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListAddressOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x12MoveAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13MoveAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t2\xc7\t\n\x0e\x41\x64\x64ressService\x12s\n\x03Get\x12&.yandex.cloud.vpc.v1.GetAddressRequest\x1a\x1c.yandex.cloud.vpc.v1.Address\"&\x82\xd3\xe4\x93\x02 \x12\x1e/vpc/v1/addresses/{address_id}\x12|\n\nGetByValue\x12-.yandex.cloud.vpc.v1.GetAddressByValueRequest\x1a\x1c.yandex.cloud.vpc.v1.Address\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/vpc/v1/addresses:byValue\x12x\n\x04List\x12).yandex.cloud.vpc.v1.ListAddressesRequest\x1a*.yandex.cloud.vpc.v1.ListAddressesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/vpc/v1/addresses\x12\x98\x01\n\x06\x43reate\x12).yandex.cloud.vpc.v1.CreateAddressRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2* \n\x15\x43reateAddressMetadata\x12\x07\x41\x64\x64ress\x82\xd3\xe4\x93\x02\x16\"\x11/vpc/v1/addresses:\x01*\x12\xa5\x01\n\x06Update\x12).yandex.cloud.vpc.v1.UpdateAddressRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2* \n\x15UpdateAddressMetadata\x12\x07\x41\x64\x64ress\x82\xd3\xe4\x93\x02#2\x1e/vpc/v1/addresses/{address_id}:\x01*\x12\xb0\x01\n\x06\x44\x65lete\x12).yandex.cloud.vpc.v1.DeleteAddressRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*.\n\x15\x44\x65leteAddressMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02 *\x1e/vpc/v1/addresses/{address_id}\x12\xaa\x01\n\x0eListOperations\x12\x31.yandex.cloud.vpc.v1.ListAddressOperationsRequest\x1a\x32.yandex.cloud.vpc.v1.ListAddressOperationsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/vpc/v1/addresses/{address_id}/operations\x12\xa4\x01\n\x04Move\x12\'.yandex.cloud.vpc.v1.MoveAddressRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*\x1e\n\x13MoveAddressMetadata\x12\x07\x41\x64\x64ress\x82\xd3\xe4\x93\x02(\"#/vpc/v1/addresses/{address_id}:move:\x01*BV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.address_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _GETADDRESSREQUEST.fields_by_name['address_id']._options = None
  _GETADDRESSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTADDRESSESREQUEST.fields_by_name['folder_id']._options = None
  _LISTADDRESSESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTADDRESSESREQUEST.fields_by_name['page_size']._options = None
  _LISTADDRESSESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTADDRESSESREQUEST.fields_by_name['page_token']._options = None
  _LISTADDRESSESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEADDRESSREQUEST_LABELSENTRY._options = None
  _CREATEADDRESSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEADDRESSREQUEST.fields_by_name['folder_id']._options = None
  _CREATEADDRESSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEADDRESSREQUEST.fields_by_name['name']._options = None
  _CREATEADDRESSREQUEST.fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _CREATEADDRESSREQUEST.fields_by_name['description']._options = None
  _CREATEADDRESSREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEADDRESSREQUEST.fields_by_name['labels']._options = None
  _CREATEADDRESSREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _DNSRECORDSPEC.fields_by_name['fqdn']._options = None
  _DNSRECORDSPEC.fields_by_name['fqdn']._serialized_options = b'\350\3071\001'
  _DNSRECORDSPEC.fields_by_name['dns_zone_id']._options = None
  _DNSRECORDSPEC.fields_by_name['dns_zone_id']._serialized_options = b'\350\3071\001\212\3101\00220'
  _DNSRECORDSPEC.fields_by_name['ttl']._options = None
  _DNSRECORDSPEC.fields_by_name['ttl']._serialized_options = b'\372\3071\0070-86400'
  _UPDATEADDRESSREQUEST_LABELSENTRY._options = None
  _UPDATEADDRESSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEADDRESSREQUEST.fields_by_name['address_id']._options = None
  _UPDATEADDRESSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEADDRESSREQUEST.fields_by_name['name']._options = None
  _UPDATEADDRESSREQUEST.fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _UPDATEADDRESSREQUEST.fields_by_name['description']._options = None
  _UPDATEADDRESSREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEADDRESSREQUEST.fields_by_name['labels']._options = None
  _UPDATEADDRESSREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _DELETEADDRESSREQUEST.fields_by_name['address_id']._options = None
  _DELETEADDRESSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['address_id']._options = None
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _MOVEADDRESSREQUEST.fields_by_name['address_id']._options = None
  _MOVEADDRESSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVEADDRESSREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVEADDRESSREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDRESSSERVICE.methods_by_name['Get']._options = None
  _ADDRESSSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002 \022\036/vpc/v1/addresses/{address_id}'
  _ADDRESSSERVICE.methods_by_name['GetByValue']._options = None
  _ADDRESSSERVICE.methods_by_name['GetByValue']._serialized_options = b'\202\323\344\223\002\033\022\031/vpc/v1/addresses:byValue'
  _ADDRESSSERVICE.methods_by_name['List']._options = None
  _ADDRESSSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/vpc/v1/addresses'
  _ADDRESSSERVICE.methods_by_name['Create']._options = None
  _ADDRESSSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateAddressMetadata\022\007Address\202\323\344\223\002\026\"\021/vpc/v1/addresses:\001*'
  _ADDRESSSERVICE.methods_by_name['Update']._options = None
  _ADDRESSSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateAddressMetadata\022\007Address\202\323\344\223\002#2\036/vpc/v1/addresses/{address_id}:\001*'
  _ADDRESSSERVICE.methods_by_name['Delete']._options = None
  _ADDRESSSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteAddressMetadata\022\025google.protobuf.Empty\202\323\344\223\002 *\036/vpc/v1/addresses/{address_id}'
  _ADDRESSSERVICE.methods_by_name['ListOperations']._options = None
  _ADDRESSSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002+\022)/vpc/v1/addresses/{address_id}/operations'
  _ADDRESSSERVICE.methods_by_name['Move']._options = None
  _ADDRESSSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveAddressMetadata\022\007Address\202\323\344\223\002(\"#/vpc/v1/addresses/{address_id}:move:\001*'
  _globals['_GETADDRESSREQUEST']._serialized_start=270
  _globals['_GETADDRESSREQUEST']._serialized_end=323
  _globals['_GETADDRESSBYVALUEREQUEST']._serialized_start=325
  _globals['_GETADDRESSBYVALUEREQUEST']._serialized_end=395
  _globals['_LISTADDRESSESREQUEST']._serialized_start=398
  _globals['_LISTADDRESSESREQUEST']._serialized_end=531
  _globals['_LISTADDRESSESRESPONSE']._serialized_start=533
  _globals['_LISTADDRESSESRESPONSE']._serialized_end=630
  _globals['_CREATEADDRESSREQUEST']._serialized_start=633
  _globals['_CREATEADDRESSREQUEST']._serialized_end=1159
  _globals['_CREATEADDRESSREQUEST_LABELSENTRY']._serialized_start=1092
  _globals['_CREATEADDRESSREQUEST_LABELSENTRY']._serialized_end=1137
  _globals['_EXTERNALIPV4ADDRESSSPEC']._serialized_start=1161
  _globals['_EXTERNALIPV4ADDRESSSPEC']._serialized_end=1284
  _globals['_DNSRECORDSPEC']._serialized_start=1286
  _globals['_DNSRECORDSPEC']._serialized_end=1393
  _globals['_CREATEADDRESSMETADATA']._serialized_start=1395
  _globals['_CREATEADDRESSMETADATA']._serialized_end=1438
  _globals['_UPDATEADDRESSREQUEST']._serialized_start=1441
  _globals['_UPDATEADDRESSREQUEST']._serialized_end=1929
  _globals['_UPDATEADDRESSREQUEST_LABELSENTRY']._serialized_start=1092
  _globals['_UPDATEADDRESSREQUEST_LABELSENTRY']._serialized_end=1137
  _globals['_UPDATEADDRESSMETADATA']._serialized_start=1931
  _globals['_UPDATEADDRESSMETADATA']._serialized_end=1974
  _globals['_DELETEADDRESSREQUEST']._serialized_start=1976
  _globals['_DELETEADDRESSREQUEST']._serialized_end=2032
  _globals['_DELETEADDRESSMETADATA']._serialized_start=2034
  _globals['_DELETEADDRESSMETADATA']._serialized_end=2077
  _globals['_LISTADDRESSOPERATIONSREQUEST']._serialized_start=2079
  _globals['_LISTADDRESSOPERATIONSREQUEST']._serialized_end=2205
  _globals['_LISTADDRESSOPERATIONSRESPONSE']._serialized_start=2207
  _globals['_LISTADDRESSOPERATIONSRESPONSE']._serialized_end=2318
  _globals['_MOVEADDRESSREQUEST']._serialized_start=2320
  _globals['_MOVEADDRESSREQUEST']._serialized_end=2419
  _globals['_MOVEADDRESSMETADATA']._serialized_start=2421
  _globals['_MOVEADDRESSMETADATA']._serialized_end=2462
  _globals['_ADDRESSSERVICE']._serialized_start=2465
  _globals['_ADDRESSSERVICE']._serialized_end=3688
# @@protoc_insertion_point(module_scope)
