"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GroupMappingItem(google.protobuf.message.Message):
    """Group mapping represents which external (federated) groups should match which internal (cloud) groups"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_GROUP_ID_FIELD_NUMBER: builtins.int
    INTERNAL_GROUP_ID_FIELD_NUMBER: builtins.int
    external_group_id: builtins.str
    """External group id (received from identity provider)"""
    internal_group_id: builtins.str
    """Internal cloud group id"""
    def __init__(
        self,
        *,
        external_group_id: builtins.str = ...,
        internal_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_group_id", b"external_group_id", "internal_group_id", b"internal_group_id"]) -> None: ...

global___GroupMappingItem = GroupMappingItem

@typing.final
class GroupMapping(google.protobuf.message.Message):
    """Group synchronization status for a specific federation
    Absence of this object for a federation means that there is no group synchronization set of for the federation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """Federation id"""
    enabled: builtins.bool
    """Flag to show whether group synchronization should be enabled for this federation."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "federation_id", b"federation_id"]) -> None: ...

global___GroupMapping = GroupMapping
