# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/smartcaptcha/v1/captcha.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/smartcaptcha/v1/captcha.proto\x12\x1cyandex.cloud.smartcaptcha.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xa4\x05\n\x07\x43\x61ptcha\x12\n\n\x02id\x18\x15 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x0c \x01(\t\x12\x12\n\nclient_key\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x15\n\rallowed_sites\x18\x08 \x03(\t\x12\x43\n\ncomplexity\x18\t \x01(\x0e\x32/.yandex.cloud.smartcaptcha.v1.CaptchaComplexity\x12\x12\n\nstyle_json\x18\n \x01(\t\x12\x0f\n\x07suspend\x18\r \x01(\x08\x12\x1f\n\x17turn_off_hostname_check\x18\x0e \x01(\x08\x12I\n\x0epre_check_type\x18\x10 \x01(\x0e\x32\x31.yandex.cloud.smartcaptcha.v1.CaptchaPreCheckType\x12J\n\x0e\x63hallenge_type\x18\x11 \x01(\x0e\x32\x32.yandex.cloud.smartcaptcha.v1.CaptchaChallengeType\x12\x42\n\x0esecurity_rules\x18\x13 \x03(\x0b\x32*.yandex.cloud.smartcaptcha.v1.SecurityRule\x12\x1b\n\x13\x64\x65letion_protection\x18\x16 \x01(\x08\x12R\n\x11override_variants\x18\x17 \x03(\x0b\x32-.yandex.cloud.smartcaptcha.v1.OverrideVariantB\x08\x82\xc8\x31\x04<=32J\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x0b\x10\x0cJ\x04\x08\x0f\x10\x10J\x04\x08\x12\x10\x13J\x04\x08\x14\x10\x15\"\xc3\x02\n\x0fOverrideVariant\x12\x34\n\x04uuid\x18\x01 \x01(\tB&\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04<=64\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12\x43\n\ncomplexity\x18\x03 \x01(\x0e\x32/.yandex.cloud.smartcaptcha.v1.CaptchaComplexity\x12I\n\x0epre_check_type\x18\x04 \x01(\x0e\x32\x31.yandex.cloud.smartcaptcha.v1.CaptchaPreCheckType\x12J\n\x0e\x63hallenge_type\x18\x05 \x01(\x0e\x32\x32.yandex.cloud.smartcaptcha.v1.CaptchaChallengeType\"&\n\x10\x43\x61ptchaSecretKey\x12\x12\n\nserver_key\x18\x01 \x01(\t\"\xe9\x01\n\x0cSecurityRule\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04\x31-50\x12\x1e\n\x08priority\x18\x02 \x01(\x03\x42\x0c\xfa\xc7\x31\x08\x31-999999\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12:\n\tcondition\x18\x04 \x01(\x0b\x32\'.yandex.cloud.smartcaptcha.v1.Condition\x12\x1d\n\x15override_variant_uuid\x18\x06 \x01(\tJ\x04\x08\x05\x10\x06\"\xd6\x0b\n\tCondition\x12\x41\n\x04host\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.smartcaptcha.v1.Condition.HostMatcher\x12?\n\x03uri\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.smartcaptcha.v1.Condition.UriMatcher\x12P\n\x07headers\x18\x03 \x03(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.HeaderMatcherB\x08\x82\xc8\x31\x04<=20\x12\x44\n\tsource_ip\x18\x04 \x01(\x0b\x32\x31.yandex.cloud.smartcaptcha.v1.Condition.IpMatcher\x1a\xfc\x01\n\rStringMatcher\x12 \n\x0b\x65xact_match\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12$\n\x0f\x65xact_not_match\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12!\n\x0cprefix_match\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12%\n\x10prefix_not_match\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12%\n\x10pire_regex_match\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12)\n\x14pire_regex_not_match\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x42\x07\n\x05match\x1a]\n\x0bHostMatcher\x12N\n\x05hosts\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.StringMatcherB\x08\x82\xc8\x31\x04<=20\x1a\xa2\x01\n\nUriMatcher\x12\x43\n\x04path\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.StringMatcher\x12O\n\x07queries\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.smartcaptcha.v1.Condition.QueryMatcherB\x08\x82\xc8\x31\x04<=20\x1av\n\x0cQueryMatcher\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-255\x12J\n\x05value\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.StringMatcherB\x04\xe8\xc7\x31\x01\x1ax\n\rHeaderMatcher\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-255\x12J\n\x05value\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.StringMatcherB\x04\xe8\xc7\x31\x01\x1a\xcf\x02\n\tIpMatcher\x12P\n\x0fip_ranges_match\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.smartcaptcha.v1.Condition.IpRangesMatcher\x12T\n\x13ip_ranges_not_match\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.smartcaptcha.v1.Condition.IpRangesMatcher\x12J\n\x0cgeo_ip_match\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.smartcaptcha.v1.Condition.GeoIpMatcher\x12N\n\x10geo_ip_not_match\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.smartcaptcha.v1.Condition.GeoIpMatcher\x1a\x31\n\x0fIpRangesMatcher\x12\x1e\n\tip_ranges\x18\x01 \x03(\tB\x0b\x82\xc8\x31\x07<=10000\x1a\x33\n\x0cGeoIpMatcher\x12#\n\tlocations\x18\x01 \x03(\tB\x10\x82\xc8\x31\x03>=1\x8a\xc8\x31\x01\x32\x90\xc8\x31\x01*g\n\x11\x43\x61ptchaComplexity\x12\"\n\x1e\x43\x41PTCHA_COMPLEXITY_UNSPECIFIED\x10\x00\x12\x08\n\x04\x45\x41SY\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\x08\n\x04HARD\x10\x03\x12\x0e\n\nFORCE_HARD\x10\x04*W\n\x13\x43\x61ptchaPreCheckType\x12&\n\"CAPTCHA_PRE_CHECK_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43HECKBOX\x10\x01\x12\n\n\x06SLIDER\x10\x02*q\n\x14\x43\x61ptchaChallengeType\x12&\n\"CAPTCHA_CHALLENGE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nIMAGE_TEXT\x10\x01\x12\x0f\n\x0bSILHOUETTES\x10\x02\x12\x10\n\x0cKALEIDOSCOPE\x10\x03\x42q\n yandex.cloud.api.smartcaptcha.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartcaptcha/v1;smartcaptchab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartcaptcha.v1.captcha_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.smartcaptcha.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartcaptcha/v1;smartcaptcha'
  _CAPTCHA.fields_by_name['override_variants']._options = None
  _CAPTCHA.fields_by_name['override_variants']._serialized_options = b'\202\3101\004<=32'
  _OVERRIDEVARIANT.fields_by_name['uuid']._options = None
  _OVERRIDEVARIANT.fields_by_name['uuid']._serialized_options = b'\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\004<=64'
  _OVERRIDEVARIANT.fields_by_name['description']._options = None
  _OVERRIDEVARIANT.fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _SECURITYRULE.fields_by_name['name']._options = None
  _SECURITYRULE.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\0041-50'
  _SECURITYRULE.fields_by_name['priority']._options = None
  _SECURITYRULE.fields_by_name['priority']._serialized_options = b'\372\3071\0101-999999'
  _SECURITYRULE.fields_by_name['description']._options = None
  _SECURITYRULE.fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _CONDITION_STRINGMATCHER.fields_by_name['exact_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['exact_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['exact_not_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['exact_not_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_not_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_not_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_not_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_not_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_HOSTMATCHER.fields_by_name['hosts']._options = None
  _CONDITION_HOSTMATCHER.fields_by_name['hosts']._serialized_options = b'\202\3101\004<=20'
  _CONDITION_URIMATCHER.fields_by_name['queries']._options = None
  _CONDITION_URIMATCHER.fields_by_name['queries']._serialized_options = b'\202\3101\004<=20'
  _CONDITION_QUERYMATCHER.fields_by_name['key']._options = None
  _CONDITION_QUERYMATCHER.fields_by_name['key']._serialized_options = b'\350\3071\001\212\3101\0051-255'
  _CONDITION_QUERYMATCHER.fields_by_name['value']._options = None
  _CONDITION_QUERYMATCHER.fields_by_name['value']._serialized_options = b'\350\3071\001'
  _CONDITION_HEADERMATCHER.fields_by_name['name']._options = None
  _CONDITION_HEADERMATCHER.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\0051-255'
  _CONDITION_HEADERMATCHER.fields_by_name['value']._options = None
  _CONDITION_HEADERMATCHER.fields_by_name['value']._serialized_options = b'\350\3071\001'
  _CONDITION_IPRANGESMATCHER.fields_by_name['ip_ranges']._options = None
  _CONDITION_IPRANGESMATCHER.fields_by_name['ip_ranges']._serialized_options = b'\202\3101\007<=10000'
  _CONDITION_GEOIPMATCHER.fields_by_name['locations']._options = None
  _CONDITION_GEOIPMATCHER.fields_by_name['locations']._serialized_options = b'\202\3101\003>=1\212\3101\0012\220\3101\001'
  _CONDITION.fields_by_name['headers']._options = None
  _CONDITION.fields_by_name['headers']._serialized_options = b'\202\3101\004<=20'
  _globals['_CAPTCHACOMPLEXITY']._serialized_start=2918
  _globals['_CAPTCHACOMPLEXITY']._serialized_end=3021
  _globals['_CAPTCHAPRECHECKTYPE']._serialized_start=3023
  _globals['_CAPTCHAPRECHECKTYPE']._serialized_end=3110
  _globals['_CAPTCHACHALLENGETYPE']._serialized_start=3112
  _globals['_CAPTCHACHALLENGETYPE']._serialized_end=3225
  _globals['_CAPTCHA']._serialized_start=141
  _globals['_CAPTCHA']._serialized_end=817
  _globals['_OVERRIDEVARIANT']._serialized_start=820
  _globals['_OVERRIDEVARIANT']._serialized_end=1143
  _globals['_CAPTCHASECRETKEY']._serialized_start=1145
  _globals['_CAPTCHASECRETKEY']._serialized_end=1183
  _globals['_SECURITYRULE']._serialized_start=1186
  _globals['_SECURITYRULE']._serialized_end=1419
  _globals['_CONDITION']._serialized_start=1422
  _globals['_CONDITION']._serialized_end=2916
  _globals['_CONDITION_STRINGMATCHER']._serialized_start=1720
  _globals['_CONDITION_STRINGMATCHER']._serialized_end=1972
  _globals['_CONDITION_HOSTMATCHER']._serialized_start=1974
  _globals['_CONDITION_HOSTMATCHER']._serialized_end=2067
  _globals['_CONDITION_URIMATCHER']._serialized_start=2070
  _globals['_CONDITION_URIMATCHER']._serialized_end=2232
  _globals['_CONDITION_QUERYMATCHER']._serialized_start=2234
  _globals['_CONDITION_QUERYMATCHER']._serialized_end=2352
  _globals['_CONDITION_HEADERMATCHER']._serialized_start=2354
  _globals['_CONDITION_HEADERMATCHER']._serialized_end=2474
  _globals['_CONDITION_IPMATCHER']._serialized_start=2477
  _globals['_CONDITION_IPMATCHER']._serialized_end=2812
  _globals['_CONDITION_IPRANGESMATCHER']._serialized_start=2814
  _globals['_CONDITION_IPRANGESMATCHER']._serialized_end=2863
  _globals['_CONDITION_GEOIPMATCHER']._serialized_start=2865
  _globals['_CONDITION_GEOIPMATCHER']._serialized_end=2916
# @@protoc_insertion_point(module_scope)
