# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/storage/v1/bucket.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/storage/v1/bucket.proto\x12\x17yandex.cloud.storage.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xc7\x05\n\x06\x42ucket\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12M\n\x16\x61nonymous_access_flags\x18\x04 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12\x1d\n\x15\x64\x65\x66\x61ult_storage_class\x18\x05 \x01(\t\x12\x37\n\nversioning\x18\x06 \x01(\x0e\x32#.yandex.cloud.storage.v1.Versioning\x12\x10\n\x08max_size\x18\x07 \x01(\x03\x12\'\n\x06policy\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x03\x61\x63l\x18\t \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.ACL\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x04\x63ors\x18\x0b \x03(\x0b\x32!.yandex.cloud.storage.v1.CorsRule\x12\x42\n\x10website_settings\x18\x0c \x01(\x0b\x32(.yandex.cloud.storage.v1.WebsiteSettings\x12?\n\x0flifecycle_rules\x18\r \x03(\x0b\x32&.yandex.cloud.storage.v1.LifecycleRule\x12*\n\x04tags\x18\x0e \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\x12\x38\n\x0bobject_lock\x18\x0f \x01(\x0b\x32#.yandex.cloud.storage.v1.ObjectLock\x12\x37\n\nencryption\x18\x10 \x01(\x0b\x32#.yandex.cloud.storage.v1.Encryption\"!\n\x03Tag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x92\x04\n\x03\x41\x43L\x12\x32\n\x06grants\x18\x01 \x03(\x0b\x32\".yandex.cloud.storage.v1.ACL.Grant\x1a\xd6\x03\n\x05Grant\x12G\n\npermission\x18\x01 \x01(\x0e\x32-.yandex.cloud.storage.v1.ACL.Grant.PermissionB\x04\xe8\xc7\x31\x01\x12\x46\n\ngrant_type\x18\x02 \x01(\x0e\x32,.yandex.cloud.storage.v1.ACL.Grant.GrantTypeB\x04\xe8\xc7\x31\x01\x12\x12\n\ngrantee_id\x18\x03 \x01(\t\"\xa3\x01\n\nPermission\x12\x1a\n\x16PERMISSION_UNSPECIFIED\x10\x00\x12\x1b\n\x17PERMISSION_FULL_CONTROL\x10\x01\x12\x14\n\x10PERMISSION_WRITE\x10\x02\x12\x18\n\x14PERMISSION_WRITE_ACP\x10\x03\x12\x13\n\x0fPERMISSION_READ\x10\x04\x12\x17\n\x13PERMISSION_READ_ACP\x10\x05\"\x81\x01\n\tGrantType\x12\x1a\n\x16GRANT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12GRANT_TYPE_ACCOUNT\x10\x01\x12&\n\"GRANT_TYPE_ALL_AUTHENTICATED_USERS\x10\x02\x12\x18\n\x14GRANT_TYPE_ALL_USERS\x10\x03\"\x9b\x01\n\x14\x41nonymousAccessFlags\x12(\n\x04read\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n\x04list\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0b\x63onfig_read\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xe4\x02\n\x08\x43orsRule\x12\n\n\x02id\x18\x01 \x01(\t\x12M\n\x0f\x61llowed_methods\x18\x02 \x03(\x0e\x32(.yandex.cloud.storage.v1.CorsRule.MethodB\n\x82\xc8\x31\x02>0\x90\xc8\x31\x01\x12\x17\n\x0f\x61llowed_headers\x18\x03 \x03(\t\x12\x1f\n\x0f\x61llowed_origins\x18\x04 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x16\n\x0e\x65xpose_headers\x18\x05 \x03(\t\x12\x34\n\x0fmax_age_seconds\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"u\n\x06Method\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x0e\n\nMETHOD_GET\x10\x01\x12\x0f\n\x0bMETHOD_HEAD\x10\x02\x12\x0f\n\x0bMETHOD_POST\x10\x03\x12\x0e\n\nMETHOD_PUT\x10\x04\x12\x11\n\rMETHOD_DELETE\x10\x05\"\xbc\x06\n\x0fWebsiteSettings\x12\r\n\x05index\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12N\n\x15redirect_all_requests\x18\x03 \x01(\x0b\x32/.yandex.cloud.storage.v1.WebsiteSettings.Scheme\x12K\n\rrouting_rules\x18\x04 \x03(\x0b\x32\x34.yandex.cloud.storage.v1.WebsiteSettings.RoutingRule\x1a_\n\x06Scheme\x12\x43\n\x08protocol\x18\x01 \x01(\x0e\x32\x31.yandex.cloud.storage.v1.WebsiteSettings.Protocol\x12\x10\n\x08hostname\x18\x02 \x01(\t\x1aO\n\tCondition\x12\'\n\x1fhttp_error_code_returned_equals\x18\x01 \x01(\t\x12\x19\n\x11key_prefix_equals\x18\x02 \x01(\t\x1a\xd2\x01\n\x08Redirect\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x34\n\x12http_redirect_code\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x14\x33(0[1-9]|[1-9][0-9])\x12\x43\n\x08protocol\x18\x03 \x01(\x0e\x32\x31.yandex.cloud.storage.v1.WebsiteSettings.Protocol\x12\x1f\n\x17replace_key_prefix_with\x18\x04 \x01(\t\x12\x18\n\x10replace_key_with\x18\x05 \x01(\t\x1a\x99\x01\n\x0bRoutingRule\x12\x45\n\tcondition\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.storage.v1.WebsiteSettings.Condition\x12\x43\n\x08redirect\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.storage.v1.WebsiteSettings.Redirect\"K\n\x08Protocol\x12\x18\n\x14PROTOCOL_UNSPECIFIED\x10\x00\x12\x11\n\rPROTOCOL_HTTP\x10\x01\x12\x12\n\x0ePROTOCOL_HTTPS\x10\x02\"\xe5\r\n\rLifecycleRule\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x41\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.storage.v1.LifecycleRule.RuleFilter\x12\x45\n\nexpiration\x18\x04 \x01(\x0b\x32\x31.yandex.cloud.storage.v1.LifecycleRule.Expiration\x12\x46\n\x0btransitions\x18\x05 \x03(\x0b\x32\x31.yandex.cloud.storage.v1.LifecycleRule.Transition\x12[\n!abort_incomplete_multipart_upload\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.storage.v1.LifecycleRule.AfterDays\x12Z\n\x15noncurrent_expiration\x18\x07 \x01(\x0b\x32;.yandex.cloud.storage.v1.LifecycleRule.NoncurrentExpiration\x12[\n\x16noncurrent_transitions\x18\x08 \x03(\x0b\x32;.yandex.cloud.storage.v1.LifecycleRule.NoncurrentTransition\x12\x61\n\x19noncurrent_delete_markers\x18\t \x01(\x0b\x32>.yandex.cloud.storage.v1.LifecycleRule.NoncurrentDeleteMarkers\x1aG\n\tAfterDays\x12:\n\x15\x64\x61ys_after_expiration\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1aO\n\x17NoncurrentDeleteMarkers\x12\x34\n\x0fnoncurrent_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1aL\n\x14NoncurrentExpiration\x12\x34\n\x0fnoncurrent_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1ai\n\x14NoncurrentTransition\x12\x34\n\x0fnoncurrent_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1b\n\rstorage_class\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x1a\x84\x01\n\nTransition\x12(\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x04\x64\x61ys\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1b\n\rstorage_class\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01J\x04\x08\x03\x10\x04\x1a\xa3\x01\n\nExpiration\x12(\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x04\x64\x61ys\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1c\x65xpired_object_delete_marker\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xcd\x03\n\nRuleFilter\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12=\n\x18object_size_greater_than\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15object_size_less_than\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12)\n\x03tag\x18\x04 \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\x12K\n\x0c\x61nd_operator\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.storage.v1.LifecycleRule.RuleFilter.And\x1a\xbb\x01\n\x03\x41nd\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12=\n\x18object_size_greater_than\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15object_size_less_than\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12)\n\x03tag\x18\x04 \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\"\xdd\x01\n\x08\x43ounters\x12\x1a\n\x12simple_object_size\x18\x01 \x01(\x03\x12\x1b\n\x13simple_object_count\x18\x02 \x01(\x03\x12\x1a\n\x12objects_parts_size\x18\x03 \x01(\x03\x12\x1b\n\x13objects_parts_count\x18\x04 \x01(\x03\x12\x1e\n\x16multipart_objects_size\x18\x05 \x01(\x03\x12\x1f\n\x17multipart_objects_count\x18\x06 \x01(\x03\x12\x1e\n\x16\x61\x63tive_multipart_count\x18\x07 \x01(\x03\"]\n\x13OptionalSizeByClass\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12/\n\nclass_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"8\n\x0bSizeByClass\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12\x12\n\nclass_size\x18\x02 \x01(\x03\"]\n\x0f\x43ountersByClass\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12\x33\n\x08\x63ounters\x18\x02 \x01(\x0b\x32!.yandex.cloud.storage.v1.Counters\"\xaa\x04\n\x0b\x42ucketStats\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x08max_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x11\n\tused_size\x18\x03 \x01(\x03\x12M\n\x17storage_class_max_sizes\x18\x04 \x03(\x0b\x32,.yandex.cloud.storage.v1.OptionalSizeByClass\x12\x46\n\x18storage_class_used_sizes\x18\x05 \x03(\x0b\x32$.yandex.cloud.storage.v1.SizeByClass\x12H\n\x16storage_class_counters\x18\x06 \x03(\x0b\x32(.yandex.cloud.storage.v1.CountersByClass\x12;\n\x15\x64\x65\x66\x61ult_storage_class\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12M\n\x16\x61nonymous_access_flags\x18\x08 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc1\x03\n\x0bHTTPSConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x0bsource_type\x18\x02 \x01(\x0e\x32/.yandex.cloud.storage.v1.HTTPSConfig.SourceType\x12,\n\x06issuer\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07subject\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x11\n\tdns_names\x18\x05 \x03(\t\x12.\n\nnot_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tnot_after\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63\x65rtificate_id\x18\x08 \x01(\t\"w\n\nSourceType\x12\x1b\n\x17SOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18SOURCE_TYPE_SELF_MANAGED\x10\x01\x12.\n*SOURCE_TYPE_MANAGED_BY_CERTIFICATE_MANAGER\x10\x02\"\xf3\x03\n\nObjectLock\x12\x44\n\x06status\x18\x02 \x01(\x0e\x32\x34.yandex.cloud.storage.v1.ObjectLock.ObjectLockStatus\x12O\n\x11\x64\x65\x66\x61ult_retention\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.storage.v1.ObjectLock.DefaultRetention\x1a\xd4\x01\n\x10\x44\x65\x66\x61ultRetention\x12G\n\x04mode\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.storage.v1.ObjectLock.DefaultRetention.Mode\x12\x0e\n\x04\x64\x61ys\x18\x02 \x01(\x03H\x00\x12\x0f\n\x05years\x18\x03 \x01(\x03H\x00\"F\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0fMODE_GOVERNANCE\x10\x01\x12\x13\n\x0fMODE_COMPLIANCE\x10\x02\x42\x0e\n\x06period\x12\x04\xc0\xc1\x31\x01\"w\n\x10ObjectLockStatus\x12\"\n\x1eOBJECT_LOCK_STATUS_UNSPECIFIED\x10\x00\x12\x1f\n\x1bOBJECT_LOCK_STATUS_DISABLED\x10\x01\x12\x1e\n\x1aOBJECT_LOCK_STATUS_ENABLED\x10\x02\"\x93\x01\n\nEncryption\x12\x41\n\x05rules\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.storage.v1.Encryption.EncryptionRule\x1a\x42\n\x0e\x45ncryptionRule\x12\x19\n\x11kms_master_key_id\x18\x01 \x01(\t\x12\x15\n\rsse_algorithm\x18\x02 \x01(\t*s\n\nVersioning\x12\x1a\n\x16VERSIONING_UNSPECIFIED\x10\x00\x12\x17\n\x13VERSIONING_DISABLED\x10\x01\x12\x16\n\x12VERSIONING_ENABLED\x10\x02\x12\x18\n\x14VERSIONING_SUSPENDED\x10\x03\x42\x62\n\x1byandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.storage.v1.bucket_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storage'
  _ACL_GRANT.fields_by_name['permission']._options = None
  _ACL_GRANT.fields_by_name['permission']._serialized_options = b'\350\3071\001'
  _ACL_GRANT.fields_by_name['grant_type']._options = None
  _ACL_GRANT.fields_by_name['grant_type']._serialized_options = b'\350\3071\001'
  _CORSRULE.fields_by_name['allowed_methods']._options = None
  _CORSRULE.fields_by_name['allowed_methods']._serialized_options = b'\202\3101\002>0\220\3101\001'
  _CORSRULE.fields_by_name['allowed_origins']._options = None
  _CORSRULE.fields_by_name['allowed_origins']._serialized_options = b'\202\3101\002>0'
  _WEBSITESETTINGS_REDIRECT.fields_by_name['http_redirect_code']._options = None
  _WEBSITESETTINGS_REDIRECT.fields_by_name['http_redirect_code']._serialized_options = b'\362\3071\0243(0[1-9]|[1-9][0-9])'
  _LIFECYCLERULE_NONCURRENTTRANSITION.fields_by_name['storage_class']._options = None
  _LIFECYCLERULE_NONCURRENTTRANSITION.fields_by_name['storage_class']._serialized_options = b'\350\3071\001'
  _LIFECYCLERULE_TRANSITION.fields_by_name['storage_class']._options = None
  _LIFECYCLERULE_TRANSITION.fields_by_name['storage_class']._serialized_options = b'\350\3071\001'
  _OBJECTLOCK_DEFAULTRETENTION.oneofs_by_name['period']._options = None
  _OBJECTLOCK_DEFAULTRETENTION.oneofs_by_name['period']._serialized_options = b'\300\3011\001'
  _globals['_VERSIONING']._serialized_start=6722
  _globals['_VERSIONING']._serialized_end=6837
  _globals['_BUCKET']._serialized_start=192
  _globals['_BUCKET']._serialized_end=903
  _globals['_TAG']._serialized_start=905
  _globals['_TAG']._serialized_end=938
  _globals['_ACL']._serialized_start=941
  _globals['_ACL']._serialized_end=1471
  _globals['_ACL_GRANT']._serialized_start=1001
  _globals['_ACL_GRANT']._serialized_end=1471
  _globals['_ACL_GRANT_PERMISSION']._serialized_start=1176
  _globals['_ACL_GRANT_PERMISSION']._serialized_end=1339
  _globals['_ACL_GRANT_GRANTTYPE']._serialized_start=1342
  _globals['_ACL_GRANT_GRANTTYPE']._serialized_end=1471
  _globals['_ANONYMOUSACCESSFLAGS']._serialized_start=1474
  _globals['_ANONYMOUSACCESSFLAGS']._serialized_end=1629
  _globals['_CORSRULE']._serialized_start=1632
  _globals['_CORSRULE']._serialized_end=1988
  _globals['_CORSRULE_METHOD']._serialized_start=1871
  _globals['_CORSRULE_METHOD']._serialized_end=1988
  _globals['_WEBSITESETTINGS']._serialized_start=1991
  _globals['_WEBSITESETTINGS']._serialized_end=2819
  _globals['_WEBSITESETTINGS_SCHEME']._serialized_start=2197
  _globals['_WEBSITESETTINGS_SCHEME']._serialized_end=2292
  _globals['_WEBSITESETTINGS_CONDITION']._serialized_start=2294
  _globals['_WEBSITESETTINGS_CONDITION']._serialized_end=2373
  _globals['_WEBSITESETTINGS_REDIRECT']._serialized_start=2376
  _globals['_WEBSITESETTINGS_REDIRECT']._serialized_end=2586
  _globals['_WEBSITESETTINGS_ROUTINGRULE']._serialized_start=2589
  _globals['_WEBSITESETTINGS_ROUTINGRULE']._serialized_end=2742
  _globals['_WEBSITESETTINGS_PROTOCOL']._serialized_start=2744
  _globals['_WEBSITESETTINGS_PROTOCOL']._serialized_end=2819
  _globals['_LIFECYCLERULE']._serialized_start=2822
  _globals['_LIFECYCLERULE']._serialized_end=4587
  _globals['_LIFECYCLERULE_AFTERDAYS']._serialized_start=3485
  _globals['_LIFECYCLERULE_AFTERDAYS']._serialized_end=3556
  _globals['_LIFECYCLERULE_NONCURRENTDELETEMARKERS']._serialized_start=3558
  _globals['_LIFECYCLERULE_NONCURRENTDELETEMARKERS']._serialized_end=3637
  _globals['_LIFECYCLERULE_NONCURRENTEXPIRATION']._serialized_start=3639
  _globals['_LIFECYCLERULE_NONCURRENTEXPIRATION']._serialized_end=3715
  _globals['_LIFECYCLERULE_NONCURRENTTRANSITION']._serialized_start=3717
  _globals['_LIFECYCLERULE_NONCURRENTTRANSITION']._serialized_end=3822
  _globals['_LIFECYCLERULE_TRANSITION']._serialized_start=3825
  _globals['_LIFECYCLERULE_TRANSITION']._serialized_end=3957
  _globals['_LIFECYCLERULE_EXPIRATION']._serialized_start=3960
  _globals['_LIFECYCLERULE_EXPIRATION']._serialized_end=4123
  _globals['_LIFECYCLERULE_RULEFILTER']._serialized_start=4126
  _globals['_LIFECYCLERULE_RULEFILTER']._serialized_end=4587
  _globals['_LIFECYCLERULE_RULEFILTER_AND']._serialized_start=4400
  _globals['_LIFECYCLERULE_RULEFILTER_AND']._serialized_end=4587
  _globals['_COUNTERS']._serialized_start=4590
  _globals['_COUNTERS']._serialized_end=4811
  _globals['_OPTIONALSIZEBYCLASS']._serialized_start=4813
  _globals['_OPTIONALSIZEBYCLASS']._serialized_end=4906
  _globals['_SIZEBYCLASS']._serialized_start=4908
  _globals['_SIZEBYCLASS']._serialized_end=4964
  _globals['_COUNTERSBYCLASS']._serialized_start=4966
  _globals['_COUNTERSBYCLASS']._serialized_end=5059
  _globals['_BUCKETSTATS']._serialized_start=5062
  _globals['_BUCKETSTATS']._serialized_end=5616
  _globals['_HTTPSCONFIG']._serialized_start=5619
  _globals['_HTTPSCONFIG']._serialized_end=6068
  _globals['_HTTPSCONFIG_SOURCETYPE']._serialized_start=5949
  _globals['_HTTPSCONFIG_SOURCETYPE']._serialized_end=6068
  _globals['_OBJECTLOCK']._serialized_start=6071
  _globals['_OBJECTLOCK']._serialized_end=6570
  _globals['_OBJECTLOCK_DEFAULTRETENTION']._serialized_start=6237
  _globals['_OBJECTLOCK_DEFAULTRETENTION']._serialized_end=6449
  _globals['_OBJECTLOCK_DEFAULTRETENTION_MODE']._serialized_start=6363
  _globals['_OBJECTLOCK_DEFAULTRETENTION_MODE']._serialized_end=6433
  _globals['_OBJECTLOCK_OBJECTLOCKSTATUS']._serialized_start=6451
  _globals['_OBJECTLOCK_OBJECTLOCKSTATUS']._serialized_end=6570
  _globals['_ENCRYPTION']._serialized_start=6573
  _globals['_ENCRYPTION']._serialized_end=6720
  _globals['_ENCRYPTION_ENCRYPTIONRULE']._serialized_start=6654
  _globals['_ENCRYPTION_ENCRYPTIONRULE']._serialized_end=6720
# @@protoc_insertion_point(module_scope)
