# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/marketplace/v1/helm_release.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/k8s/marketplace/v1/helm_release.proto\x12\x1fyandex.cloud.k8s.marketplace.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\x03\n\x0bHelmRelease\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x03 \x01(\t\x12\x15\n\rapp_namespace\x18\x04 \x01(\t\x12\x12\n\nproduct_id\x18\x05 \x01(\t\x12\x14\n\x0cproduct_name\x18\x06 \x01(\t\x12\x17\n\x0fproduct_version\x18\n \x01(\t\x12\x43\n\x06status\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.k8s.marketplace.v1.HelmRelease.Status\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xba\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0c\n\x08\x44\x45PLOYED\x10\x02\x12\x0f\n\x0bUNINSTALLED\x10\x03\x12\x0e\n\nSUPERSEDED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x10\n\x0cUNINSTALLING\x10\x06\x12\x13\n\x0fPENDING_INSTALL\x10\x07\x12\x13\n\x0fPENDING_UPGRADE\x10\x08\x12\x14\n\x10PENDING_ROLLBACK\x10\tJ\x04\x08\t\x10\nBz\n#yandex.cloud.api.k8s.marketplace.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/k8s/marketplace/v1;k8s_marketplaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.marketplace.v1.helm_release_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.k8s.marketplace.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/k8s/marketplace/v1;k8s_marketplace'
  _globals['_HELMRELEASE']._serialized_start=121
  _globals['_HELMRELEASE']._serialized_end=586
  _globals['_HELMRELEASE_STATUS']._serialized_start=394
  _globals['_HELMRELEASE_STATUS']._serialized_end=580
# @@protoc_insertion_point(module_scope)
