# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/serializers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/datatransfer/v1/endpoint/serializers.proto\x12%yandex.cloud.datatransfer.v1.endpoint\"\x10\n\x0eSerializerAuto\"\x10\n\x0eSerializerJSON\"9\n\x1b\x44\x65\x62\x65ziumSerializerParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"w\n\x12SerializerDebezium\x12\x61\n\x15serializer_parameters\x18\x01 \x03(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.DebeziumSerializerParameter\"\x98\x02\n\nSerializer\x12P\n\x0fserializer_auto\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.SerializerAutoH\x00\x12P\n\x0fserializer_json\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.SerializerJSONH\x00\x12X\n\x13serializer_debezium\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.SerializerDebeziumH\x00\x42\x0c\n\nserializerB\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.serializers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_SERIALIZERAUTO']._serialized_start=98
  _globals['_SERIALIZERAUTO']._serialized_end=114
  _globals['_SERIALIZERJSON']._serialized_start=116
  _globals['_SERIALIZERJSON']._serialized_end=132
  _globals['_DEBEZIUMSERIALIZERPARAMETER']._serialized_start=134
  _globals['_DEBEZIUMSERIALIZERPARAMETER']._serialized_end=191
  _globals['_SERIALIZERDEBEZIUM']._serialized_start=193
  _globals['_SERIALIZERDEBEZIUM']._serialized_end=312
  _globals['_SERIALIZER']._serialized_start=315
  _globals['_SERIALIZER']._serialized_end=595
# @@protoc_insertion_point(module_scope)
