"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Peering(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEERING_SUBNET_FIELD_NUMBER: builtins.int
    PEER_IP_FIELD_NUMBER: builtins.int
    CLOUD_IP_FIELD_NUMBER: builtins.int
    PEER_BGP_ASN_FIELD_NUMBER: builtins.int
    CLOUD_BGP_ASN_FIELD_NUMBER: builtins.int
    PEER_BGP_MD5_KEY_FIELD_NUMBER: builtins.int
    peering_subnet: builtins.str
    """PeeringSubnet.
    It's an ip with format ipPrefix/length where address part of ipPrefix is 0.
    """
    peer_ip: builtins.str
    """PeerIp.
    It's an ip with just an ipAddress format without mask.
    """
    cloud_ip: builtins.str
    """CloudIp.
    It's an ip with just an ipAddress format without mask.
    """
    peer_bgp_asn: builtins.int
    """PeerBgpAsn.
    PeerAsn excluding rfc5398 (excluding 64496 - 64511 and 65536 - 65551).
    """
    cloud_bgp_asn: builtins.int
    """CloudBgpAsn."""
    peer_bgp_md5_key: builtins.str
    """PeerBgpMd5Key.
    Optional.
    """
    def __init__(
        self,
        *,
        peering_subnet: builtins.str = ...,
        peer_ip: builtins.str = ...,
        cloud_ip: builtins.str = ...,
        peer_bgp_asn: builtins.int = ...,
        cloud_bgp_asn: builtins.int = ...,
        peer_bgp_md5_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cloud_bgp_asn", b"cloud_bgp_asn", "cloud_ip", b"cloud_ip", "peer_bgp_asn", b"peer_bgp_asn", "peer_bgp_md5_key", b"peer_bgp_md5_key", "peer_ip", b"peer_ip", "peering_subnet", b"peering_subnet"]) -> None: ...

global___Peering = Peering
