# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_crypto_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQyandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_crypto_service.proto\x12\'yandex.cloud.kms.v1.asymmetricsignature\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"W\n\x15\x41symmetricSignRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\x07message\x18\x02 \x01(\x0c\x42\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=32768\";\n\x16\x41symmetricSignResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"W\n\x19\x41symmetricSignHashRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x04hash\x18\x02 \x01(\x0c\x42\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=4096\"?\n\x1a\x41symmetricSignHashResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"=\n\x1d\x41symmetricGetPublicKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"D\n\x1e\x41symmetricGetPublicKeyResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t2\x98\x05\n AsymmetricSignatureCryptoService\x12\xc1\x01\n\x04Sign\x12>.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignRequest\x1a?.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignResponse\"8\x82\xd3\xe4\x93\x02\x32\"-/kms/v1/asymmetricSignatureKeys/{key_id}:sign:\x01*\x12\xd1\x01\n\x08SignHash\x12\x42.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashRequest\x1a\x43.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/kms/v1/asymmetricSignatureKeys/{key_id}:signHash:\x01*\x12\xdb\x01\n\x0cGetPublicKey\x12\x46.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyRequest\x1aG.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/kms/v1/asymmetricSignatureKeys/{key_id}/publicKeyBj\n\x17yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_crypto_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kms'
  _ASYMMETRICSIGNREQUEST.fields_by_name['key_id']._options = None
  _ASYMMETRICSIGNREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ASYMMETRICSIGNREQUEST.fields_by_name['message']._options = None
  _ASYMMETRICSIGNREQUEST.fields_by_name['message']._serialized_options = b'\350\3071\001\212\3101\007<=32768'
  _ASYMMETRICSIGNHASHREQUEST.fields_by_name['key_id']._options = None
  _ASYMMETRICSIGNHASHREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ASYMMETRICSIGNHASHREQUEST.fields_by_name['hash']._options = None
  _ASYMMETRICSIGNHASHREQUEST.fields_by_name['hash']._serialized_options = b'\350\3071\001\212\3101\006<=4096'
  _ASYMMETRICGETPUBLICKEYREQUEST.fields_by_name['key_id']._options = None
  _ASYMMETRICGETPUBLICKEYREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['Sign']._options = None
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['Sign']._serialized_options = b'\202\323\344\223\0022\"-/kms/v1/asymmetricSignatureKeys/{key_id}:sign:\001*'
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['SignHash']._options = None
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['SignHash']._serialized_options = b'\202\323\344\223\0026\"1/kms/v1/asymmetricSignatureKeys/{key_id}:signHash:\001*'
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['GetPublicKey']._options = None
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['GetPublicKey']._serialized_options = b'\202\323\344\223\0024\0222/kms/v1/asymmetricSignatureKeys/{key_id}/publicKey'
  _globals['_ASYMMETRICSIGNREQUEST']._serialized_start=187
  _globals['_ASYMMETRICSIGNREQUEST']._serialized_end=274
  _globals['_ASYMMETRICSIGNRESPONSE']._serialized_start=276
  _globals['_ASYMMETRICSIGNRESPONSE']._serialized_end=335
  _globals['_ASYMMETRICSIGNHASHREQUEST']._serialized_start=337
  _globals['_ASYMMETRICSIGNHASHREQUEST']._serialized_end=424
  _globals['_ASYMMETRICSIGNHASHRESPONSE']._serialized_start=426
  _globals['_ASYMMETRICSIGNHASHRESPONSE']._serialized_end=489
  _globals['_ASYMMETRICGETPUBLICKEYREQUEST']._serialized_start=491
  _globals['_ASYMMETRICGETPUBLICKEYREQUEST']._serialized_end=552
  _globals['_ASYMMETRICGETPUBLICKEYRESPONSE']._serialized_start=554
  _globals['_ASYMMETRICGETPUBLICKEYRESPONSE']._serialized_end=622
  _globals['_ASYMMETRICSIGNATURECRYPTOSERVICE']._serialized_start=625
  _globals['_ASYMMETRICSIGNATURECRYPTOSERVICE']._serialized_end=1289
# @@protoc_insertion_point(module_scope)
