"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iam.v1.workload.federated_credential_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetFederatedCredentialRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIAL_ID_FIELD_NUMBER: builtins.int
    federated_credential_id: builtins.str
    """ID of the federated credential to return.
    To get the federated credential ID, make a [FederatedCredentialService.List] request.
    """
    def __init__(
        self,
        *,
        federated_credential_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credential_id", b"federated_credential_id"]) -> None: ...

global___GetFederatedCredentialRequest = GetFederatedCredentialRequest

@typing.final
class ListFederatedCredentialsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to list federated credentials for.
    To get the the service account ID make a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListFederatedCredentialsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListFederatedCredentialsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "service_account_id", b"service_account_id"]) -> None: ...

global___ListFederatedCredentialsRequest = ListFederatedCredentialsRequest

@typing.final
class ListFederatedCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIALS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListFederatedCredentialsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListFederatedCredentialsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def federated_credentials(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.workload.federated_credential_pb2.FederatedCredential]:
        """List of federated credentials."""

    def __init__(
        self,
        *,
        federated_credentials: collections.abc.Iterable[yandex.cloud.iam.v1.workload.federated_credential_pb2.FederatedCredential] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credentials", b"federated_credentials", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFederatedCredentialsResponse = ListFederatedCredentialsResponse

@typing.final
class CreateFederatedCredentialRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    FEDERATION_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_SUBJECT_ID_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to create a federated credential for.
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    """
    federation_id: builtins.str
    """ID of the workload identity federation that is used for authentication."""
    external_subject_id: builtins.str
    """Id of the external subject."""
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        federation_id: builtins.str = ...,
        external_subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_subject_id", b"external_subject_id", "federation_id", b"federation_id", "service_account_id", b"service_account_id"]) -> None: ...

global___CreateFederatedCredentialRequest = CreateFederatedCredentialRequest

@typing.final
class CreateFederatedCredentialMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIAL_ID_FIELD_NUMBER: builtins.int
    federated_credential_id: builtins.str
    """ID of the federated credential that is being created."""
    def __init__(
        self,
        *,
        federated_credential_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credential_id", b"federated_credential_id"]) -> None: ...

global___CreateFederatedCredentialMetadata = CreateFederatedCredentialMetadata

@typing.final
class DeleteFederatedCredentialRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIAL_ID_FIELD_NUMBER: builtins.int
    federated_credential_id: builtins.str
    """ID of the federated credential key to delete.
    To get the federated credential ID, use a [FederatedCredentialService.List] request.
    """
    def __init__(
        self,
        *,
        federated_credential_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credential_id", b"federated_credential_id"]) -> None: ...

global___DeleteFederatedCredentialRequest = DeleteFederatedCredentialRequest

@typing.final
class DeleteFederatedCredentialMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATED_CREDENTIAL_ID_FIELD_NUMBER: builtins.int
    federated_credential_id: builtins.str
    """ID of the federated credential that is being deleted."""
    def __init__(
        self,
        *,
        federated_credential_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federated_credential_id", b"federated_credential_id"]) -> None: ...

global___DeleteFederatedCredentialMetadata = DeleteFederatedCredentialMetadata
